.userSettingDesktopHeader{display:flex;align-items:center;justify-content:space-between}.userSettingDesktopHeader .userSettingDesktopHeaderInfo{margin-top:-20px}.userSettingDesktopHeader .userSettingDesktopHeaderInfo span .btn{height:unset}.userSettingDesktopHeader .userSettingDesktopHeaderInfo a{font-size:12px}.userSettingDesktopHeader .userSettingDesktopHeaderInfo svg.circular-border{width:18px;height:18px;padding:2px;border-radius:50%;background:rgba(var(--button-bg-rgb), 0.12);text-align:center}
.ReasonOption{display:flex;align-items:center;padding-right:4px;padding-left:12px;border-radius:12px;background:var(--center-channel-color-08);cursor:pointer;gap:5px}
.content:has(.content-flagging-section-setting-wrapper){padding:28px 32px !important}.content-flagging-section-setting-wrapper{display:flex;flex-direction:column;gap:24px}.content-flagging-section-title{margin:unset;font-size:16px}.content-flagging-section-description,.helpText{color:var(--center-channel-color-72);font-size:14px;font-style:normal;font-weight:400}.content-flagging-section-setting{display:flex;width:100%;align-items:baseline}.content-flagging-section-setting .setting-title{min-width:290px;max-width:290px;color:var(--center-channel-color);font-size:14px;font-style:normal;font-weight:600}.content-flagging-section-setting .setting-content{display:flex;flex:1;gap:32px}.helpText{margin-top:8px}
.contentFlaggingReasons{width:100%}.contentFlaggingReasons___value-container{padding:6px 12px !important;gap:8px}
.DataGrid{width:100%;padding:2rem 2rem 2rem 2rem;background:#f5f5f5;color:var(--sys-center-channel-color)}.DataGrid .DataGrid_search{display:flex;height:48px;flex-direction:row;justify-content:space-between;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;font-weight:bold}.DataGrid .DataGrid_search .DataGrid_searchBar{position:relative;display:flex;width:300px;height:32px;box-sizing:border-box;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.2);border-radius:4px;margin-left:8px}.DataGrid .DataGrid_search .DataGrid_searchBar input{width:100%;border:0;margin-right:16px;margin-left:32px;font-size:.95em}.DataGrid .DataGrid_search .DataGrid_searchBar input:focus{outline:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_searchIcon{position:absolute;top:5px;left:10px;color:rgba(0,0,0,.5);pointer-events:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_clearButton{display:flex;align-items:center;margin-right:5px}.DataGrid .DataGrid_header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);color:rgba(0,0,0,.87);font-size:1.1em;font-weight:bold}.DataGrid .DataGrid_rows{display:flex;flex-direction:column;background:rgba(var(--sys-button-color-rgb), 0.5)}.DataGrid .DataGrid_rows .DataGrid_loading{padding-top:20px;padding-bottom:20px;margin:auto;color:rgba(0,0,0,.3);font-size:1.6rem}.DataGrid .DataGrid_rows .DataGrid_empty{width:100%;padding-top:20px;padding-bottom:20px;color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.DataGrid .DataGrid_rows .DataGrid_row{border-left:2px solid rgba(0,0,0,0)}.DataGrid .DataGrid_rows .DataGrid_row:nth-child(odd){background-color:#f5f5f5}.DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:2px solid #166de0;background-color:rgb(223.5853658537,235.7865853659,251.9146341463)}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell{overflow:hidden;margin:auto;text-overflow:ellipsis;white-space:nowrap}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions{color:rgba(61,60,64,.75)}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon{width:16px;height:16px;margin-left:8px;font-size:16px;line-height:16px}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon::before{margin:0}.DataGrid .DataGrid_row,.DataGrid .DataGrid_header{display:flex;height:auto;flex-direction:row;padding-left:18px}.DataGrid .DataGrid_row .DataGrid_cell,.DataGrid .DataGrid_header .DataGrid_cell{flex:1 0}.DataGrid .DataGrid_footer{display:flex;height:auto;flex-direction:row;padding:8px;border-top:solid 1px rgba(0,0,0,.1);border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;color:rgba(0,0,0,.5);font-size:1.1em;text-align:right}.DataGrid .DataGrid_footer .DataGrid_cell{width:100%;text-align:right}.DataGrid.customTable{padding:0;background:#fff}.DataGrid.customTable .DataGrid_header{padding:8px 0;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);color:var(--sys-center-channel-color);font-size:14px;font-weight:600;line-height:16px}.DataGrid.customTable .DataGrid_header:last-child{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_header .DataGrid_cell{padding:0 16px}.DataGrid.customTable .DataGrid_row{display:flex;min-height:40px;flex-direction:row;padding:0;border-left:none}.DataGrid.customTable .DataGrid_row:nth-child(odd){background:#fff}.DataGrid.customTable .DataGrid_row:nth-child(even){background:rgba(var(--sys-button-bg-rgb), 0.04)}.DataGrid.customTable .DataGrid_row:hover{border-left:none;background-color:rgba(var(--sys-button-bg-rgb), 0.08);color:var(--sys-center-channel-color);cursor:pointer}.DataGrid.customTable .DataGrid_row .actionIcon{width:32px}.DataGrid.customTable .DataGrid_row .actionIcon .MenuWrapper{width:32px;margin-left:auto}.DataGrid.customTable .DataGrid_row .actionIcon a i{display:none}.DataGrid.customTable .DataGrid_row .actionIcon a{display:flex;width:32px;height:32px;flex-direction:column;align-items:center;padding:8px;border-radius:4px;margin-left:auto;background:rgba(0,0,0,0);color:rgba(var(--sys-center-channel-color-rgb), 0.75);text-decoration:none}.DataGrid.customTable .DataGrid_row:hover .actionIcon a i{display:flex}.DataGrid.customTable .DataGrid_row .actionIcon a:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_row .DataGrid_cell{padding:10px 16px;margin:0;white-space:normal}.DataGrid.customTable .DataGrid_row .DataGrid_cell.actionIcon{overflow:visible;padding:4px 16px}.DataGrid.customTable .DataGrid_footer{border-bottom:none}
.Filter{position:relative;display:inline-block;padding-left:8px}.Filter .Filter_button{width:auto;height:32px;padding:0 10px;border:0;border-radius:4px;background:var(--sys-center-channel-bg);color:var(--sys-button-bg);font-size:12px}.Filter .Filter_button.Filter__active,.Filter .Filter_button:focus{background:rgba(var(--sys-button-bg-rgb), 0.12)}.Filter .Filter_button:hover{background:rgba(var(--sys-button-bg-rgb), 0.06)}.Filter .Icon{margin-right:2px;font-size:14px}.Filter .Filter_content{position:absolute;z-index:1;display:none;min-width:256px;box-sizing:border-box;padding:16px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;margin-top:4px;margin-bottom:24px;background:var(--sys-center-channel-bg);box-shadow:0 8px 24px rgba(0,0,0,.12)}.Filter .Filter_content.Filter__show{display:block}.Filter .Filter_content hr{padding:0;margin:8px -16px 8px -16px;color:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .Filter_header{display:flex;flex-direction:row;justify-content:space-between}.Filter .Filter_header .Filter_title{padding:8px;color:var(--sys-center-channel-color);font-size:14px;font-weight:bold;line-height:14px}.Filter .Filter_header .Filter_reset{padding:8px;font-size:12px;line-height:16px}.Filter .Filter_lists{white-space:nowrap}.Filter .Filter_apply{float:right}.Filter .FilterList{display:inline-block;width:160px;padding:8px;font-size:14px;vertical-align:top}.Filter .FilterList.FilterList__full{display:block;width:100%}.Filter .FilterList .FilterList_name{padding-bottom:12px;color:rgba(var(--sys-center-channel-color-rgb), 0.5);font-size:12px;font-weight:600}.Filter .FilterList .filterListSelect__control{min-height:32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);border-radius:4px;background:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px}.Filter .FilterList .filterListSelect__control:hover{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.48)}.Filter .FilterList .filterListSelect__option{background:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.8);cursor:pointer;font-size:12px}.Filter .FilterList .filterListSelect__option:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .FilterList .filterListSelect__indicator{padding:9px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);cursor:pointer}.Filter .FilterList .filterListSelect__indicator>svg{width:14px;height:14px}.Filter .FilterList .filterListSelect__indicator-separator{background-color:rgba(var(--sys-center-channel-color-rgb), 0.16)}.Filter .FilterList .filterListSelect__multi-value__remove:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16);color:inherit;cursor:pointer}.Filter .FilterList .FilterList_checkbox{color:rgba(var(--sys-center-channel-color-rgb), 0.8)}.Filter .FilterList .FilterList_checkbox input{position:relative;top:-4px;margin:0 8px 0 2px;opacity:.73;vertical-align:bottom}.Filter .FilterList .FilterList_checkbox input:checked{opacity:1}.Filter .FilterList .FilterList_checkbox label{font-weight:normal}
.TeamReviewers{width:100%;border:1px solid var(--center-channel-color-16);border-radius:8px;margin-top:24px}.TeamReviewers>.DataGrid{padding:0;background:none}.TeamReviewers>.DataGrid .DataGrid_search{height:unset;padding:16px;background:none}.TeamReviewers>.DataGrid .DataGrid_search .DataGrid_searchBar{margin-left:0}.TeamReviewers>.DataGrid .DataGrid_search .TeamReviewers__disable-all,.TeamReviewers>.DataGrid .DataGrid_search .TeamReviewers__disable-all>button{display:flex;align-items:center;margin-left:auto;background:none;text-decoration:none !important}.TeamReviewers>.DataGrid .DataGrid_rows .DataGrid_row:nth-child(odd){background:none}.TeamReviewers>.DataGrid .DataGrid_row{display:flex;padding:8px 16px;gap:32px}.TeamReviewers>.DataGrid .DataGrid_row .TeamReviewers__team{display:flex;overflow:hidden;align-items:center;gap:8px;text-overflow:ellipsis}.TeamReviewers>.DataGrid .DataGrid_row .TeamReviewers__team .TeamReviewers__team-name{overflow:hidden;flex:1;text-overflow:ellipsis}.TeamReviewers>.DataGrid .DataGrid_row .TeamIcon{background:var(--center-channel-color-08)}.TeamReviewers>.DataGrid .DataGrid_row .DataGrid_cell{display:flex;align-items:center !important;margin:0}.TeamReviewers>.DataGrid .DataGrid_row .DataGrid_cell .user-multiselector__control{margin-block:2px}.TeamReviewers>.DataGrid .DataGrid_row .DataGrid_cell:has(.UserMultiSelector){overflow:unset}.TeamReviewers>.DataGrid .DataGrid_header{background:var(--center-channel-color-04);gap:32px;padding-inline:18px}.TeamReviewers>.DataGrid .DataGrid_header>.DataGrid_cell{padding-left:0;color:var(--center-channel-color-72);font-size:12px}.TeamReviewers>.DataGrid .DataGrid_cell:nth-child(1){max-width:230px}.TeamReviewers>.DataGrid .DataGrid_cell:nth-child(2){max-width:446px}.TeamReviewers>.DataGrid .DataGrid_cell:nth-child(3){max-width:44px}.TeamReviewers>.DataGrid .DataGrid_footer{width:100%;padding:8px 16px;background:none}.TeamReviewers>.DataGrid .DataGrid_footer>.DataGrid_cell{margin-left:auto}
.teamSpecificReviewerSection{flex-direction:column}.teamSpecificReviewerSection .teamSearchWrapper{display:flex;width:100%;margin-top:16px;gap:8px}.teamSpecificReviewerSection .teamSearchWrapper #teamSearchSelect{flex:1}.teamSpecificReviewerSection .teamSearchWrapper .selectAllTeamsButton{padding:10px 20px;text-decoration:none !important}
.ContentFlaggingSettings h1.content-flagging-section-title{margin:0;font-size:16px;line-height:24px}.ContentFlaggingSettings .content-flagging-section-setting{display:flex}.ContentFlaggingSettings h5.content-flagging-section-description{margin:0}.ContentFlaggingSettings .SectionHeader-ffXwfT.fmYfjH.header>hgroup{display:flex;flex-direction:column;gap:4px}.ContentFlaggingSettings .setting-title{min-width:290px;font-size:14px;font-weight:600}.ContentFlaggingSettings .content-flagging-section-setting-wrapper{display:flex;flex-direction:column;gap:24px}.ContentFlaggingSettings .setting-content{display:flex;flex:1;font-size:14px;gap:24px}.ContentFlaggingSettings .setting-content-wrapper{display:flex;flex-direction:column;gap:8px}.ContentFlaggingSettings .admin-console-save .error-message{color:var(--dnd-indicator)}
.JobCancelButton{cursor:pointer;font-family:"Open Sans",sans-serif;font-size:20px;font-weight:600;line-height:0;text-decoration:none;vertical-align:middle}
.job-table__data-retention .job-table__table{border:none}.job-table__data-retention .table>thead>tr>th,.job-table__data-retention .table>tbody>tr>th,.job-table__data-retention .table>tfoot>tr>th,.job-table__data-retention .table>thead>tr>td,.job-table__data-retention .table>tbody>tr>td,.job-table__data-retention .table>tfoot>tr>td{border-top:none}.job-table__data-retention .table>thead>tr>th{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.job-table__data-retention .help-text{padding:10px 16px;background:rgba(var(--sys-center-channel-color-rgb), 0.04);color:var(--sys-center-channel-color)}.job-table__data-retention .cancel-button-field{width:30px}.JobTable .clickable{cursor:pointer}.JobTable .clickable:hover{background-color:rgba(0,0,0,.05)}.JobTable .DataGrid_footer{padding:8px;border-top:solid 1px rgba(0,0,0,.1);text-align:right}
.RadioSetting__label{display:flex;width:fit-content;align-items:center;margin-top:8px;margin-right:0;margin-bottom:0;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.RadioSetting__label--disabled{cursor:not-allowed;opacity:.5}.RadioSetting__input{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;margin:0;appearance:none;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;place-content:center}.RadioSetting__input:checked{border-color:var(--button-bg)}.RadioSetting__input:checked::before{transform:scale(1)}.RadioSetting__input::before{width:8px;height:8px;border-radius:50%;background:var(--button-bg);content:"";transform:scale(0);transform-origin:center center;transition:transform 200ms ease-in-out}.RadioSetting__input:disabled{cursor:not-allowed}.RadioSetting__text{cursor:pointer;font-size:14px;font-weight:400;line-height:20px}.RadioSetting__label--disabled .RadioSetting__text{cursor:not-allowed}
.LicenseSkuBadge{display:inline-flex;align-items:center;padding:2px 8px 2px 6px;border-radius:4px;margin-left:8px;background-color:rgba(var(--online-indicator-rgb), 0.12);color:var(--online-indicator);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600;gap:4px;line-height:16px;vertical-align:middle}.LicenseSkuBadge .icon{font-size:12px}
.AdminSectionPanel{border:solid 1px rgba(var(--center-channel-color-rgb), 0.12);border-radius:var(--radius-m);margin:20px 0;background-color:var(--center-channel-bg);box-shadow:var(--elevation-1)}.AdminSectionPanel__header{padding:16px 24px;border-bottom:solid 1px rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--center-channel-bg)}.AdminSectionPanel__title{display:flex;align-items:center;padding-bottom:0 !important;margin-top:10px !important;margin-bottom:0 !important;color:var(--center-channel-color);font-size:18px;font-weight:600;line-height:24px}.AdminSectionPanel__description{margin-top:0;margin-bottom:8px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;line-height:20px}.AdminSectionPanel__body{padding:24px}.AdminSectionPanel__body>*:first-child{margin-top:0}.AdminSectionPanel .AdminPanel{border:none;margin:0;box-shadow:none}
.config-section{border-radius:4px;margin-top:20px;background:#fff;box-shadow:0 2px 3px rgba(0,0,0,.08)}.config-section .admin-console__wrapper{padding:0}.config-section .section-header{padding:24px 32px;border-bottom:1px solid rgba(61,60,64,.08)}.config-section .section-header .section-title{font-size:16px;font-weight:bold}.config-section .section-header .section-subtitle{font-size:14px}.config-section .section-body{padding:28px 32px}.config-section:nth-child(1){margin-top:0}.admin-header-beta-badge{margin-right:auto;margin-inline-start:8px}
.custom-profile-attributes{border-top:1px solid rgba(61,60,64,.08);border-bottom:1px solid rgba(61,60,64,.08);margin-bottom:25px}.custom-profile-attributes .section-header{padding:24px 0px;border-bottom:none}.custom-profile-attributes .section-header .section-title{font-size:16px;font-weight:bold}.custom-profile-attributes .section-header .section-subtitle{font-size:14px}
details{padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background-color:var(--center-channel-bg)}summary{position:relative;padding:12px 12px 12px 28px;margin:-12px;cursor:pointer;font-weight:bold;transition:background .15s ease-in-out}summary:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}summary::marker{display:none}summary::before{position:absolute;top:16px;left:12px;content:"►";font-size:10px;transform:rotate(0deg);transition:transform .15s ease-in-out}details[open] summary{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-bottom:0}details[open] summary::before{transform:rotate(90deg)}details[open] .row:last-child .total-count{margin-bottom:0}.single-channel-guest-title{width:auto;cursor:pointer}.single-channel-guest-tooltip{max-width:300px}
.PolicyTable{overflow:auto}.PolicyTable .DataGrid{padding:0;background-color:rgba(var(--sys-white-rgb), 0.04)}.PolicyTable .DataGrid_search{height:4em;border-bottom:none}.PolicyTable .DataGrid_searchBar{margin-left:0 !important}.PolicyTable .DataGrid_header{padding-left:12px;font-size:1em;font-weight:600}.PolicyTable .DataGrid_header .DataGrid_cell{display:flex}.PolicyTable .DataGrid_header .DataGrid_cell[data-field=name]{justify-content:flex-start}.PolicyTable .DataGrid_header .DataGrid_cell[data-field=resources]{display:flex;align-items:left;justify-content:flex-start}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row{display:flex;min-height:40px;padding-left:12px !important;border-left:none;background-color:rgba(var(--sys-white-rgb), 0.04);cursor:pointer}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:none;background-color:rgba(0,0,0,.05)}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-name{width:100%;padding:10px 0}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-resources{width:100%;padding:10px 0;text-align:left}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-actions{display:flex;width:100%;justify-content:flex-end;padding-right:8px}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button{display:flex;width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button .icon{display:flex;align-items:center;justify-content:center;font-size:18px;line-height:18px}.PolicyTable .DataGrid_footer{border-bottom:0}.PolicyTable .policy-header{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.PolicyTable .policy-header-text h1{margin-bottom:8px;font-size:20px;font-weight:600}.PolicyTable .policy-header-text p{margin:0;color:rgba(63,67,80,.72)}.PolicyTable .policy-header .btn-primary{display:flex;align-items:center;padding:10px 16px;gap:8px}.PolicyTable .policy-header .btn-primary .icon{font-size:18px}.PolicyTable .action-wrapper{display:flex;justify-content:flex-end;padding:0 16px}.PolicyTable .action-wrapper .icon-button{display:flex;width:32px;height:32px;align-items:center;justify-content:center;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(63,67,80,.72);cursor:pointer}.PolicyTable .action-wrapper .icon-button:hover{background-color:rgba(63,67,80,.08);color:rgba(63,67,80,.8)}.PolicyTable .action-wrapper .icon-button .icon{font-size:18px}.policy-refresh-btn{display:flex;width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-size:18px;outline:none}.policy-refresh-btn:focus-visible{border-radius:4px;outline:2px solid var(--button-bg);outline-offset:2px}.policy-refresh-btn:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.policy-refresh-btn:active{background-color:rgba(var(--center-channel-color-rgb), 0.16)}.actions-column{justify-content:flex-end !important;text-align:right}.PolicyList__no-results{display:flex;flex-direction:column;align-items:center;padding:48px 0;color:rgba(var(--center-channel-color-rgb), 0.48);font-size:18px;font-weight:600;text-align:center}.PolicyList__no-results-hint{margin-top:8px;font-size:14px;font-weight:400}
#user-list-modal-dialog .modal-header{padding-bottom:0px}#user-list-modal-dialog .tabs{display:flex;padding:0 32px;border-bottom:1px solid var(--center-channel-color-16);margin-bottom:12px}#user-list-modal-dialog .tab-button{padding:10px 15px;border:none;margin-bottom:-1px;background:none;color:rgba(var(--center-channel-color-rgb), 0.64);cursor:pointer;font-weight:600}#user-list-modal-dialog .tab-button.active{border-bottom:2px solid var(--button-bg);color:var(--button-bg)}#user-list-modal-dialog .tab-button:hover:not(.active){color:var(--center-channel-color)}#user-list-modal-dialog .tab-content .filtered-user-list{height:440px;overflow-y:auto}#user-list-modal-dialog .tab-content .no-user-message{display:flex;height:440px;flex-direction:column;align-items:center;justify-content:center;color:rgba(var(--center-channel-color-rgb), 0.64);text-align:center}#user-list-modal-dialog .tab-content .no-user-message .empty-state-svg{margin-bottom:20px}#user-list-modal-dialog .tab-content .no-user-message .primary-message{padding-bottom:24px}
#job-details-modal .modal-header{padding:16px 64px 4px 32px}#job-details-modal .filtered-user-list{height:440px;cursor:pointer}#job-details-modal .modal-header-with-status{display:flex;align-items:center;font-size:26px;font-weight:600;gap:10px}#job-details-modal .status-indicator{display:inline-block;width:10px;height:10px;border-radius:50%}#job-details-modal .status-indicator.status-success{background-color:var(--online-indicator)}#job-details-modal .status-indicator.status-error{background-color:var(--error-text)}#job-details-modal .status-indicator.status-in-progress{background-color:var(--away-indicator)}#job-details-modal .status-indicator.status-pending{background-color:var(--offline-indicator)}#job-details-modal .filter-row{position:relative;padding:0 32px}#job-details-modal .filter-row .input-clear{top:16px;right:14px}#job-details-modal .filter-row #searchIcon{position:absolute;z-index:2;top:16px;left:42px;color:rgba(var(--center-channel-color-rgb), 0.64);pointer-events:none}#job-details-modal .filter-row #searchChannelsTextbox{height:48px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:none;font-size:16px;padding-inline:40px}#job-details-modal .filter-row #searchChannelsTextbox::placeholder{color:var(--center-channel-color)}#job-details-modal .filter-row #searchChannelsTextbox:focus{border:2px solid var(--button-bg)}#job-details-modal .sync-job-channel-count-label{display:flex;margin:10px 16px;color:var(--center-channel-color-64);font-size:12px}#job-details-modal .changes-cell{text-align:center}#job-details-modal .changes-cell .changes-summary .added{color:var(--online-indicator);font-weight:600}#job-details-modal .changes-cell .changes-summary .removed{color:var(--error-text);font-weight:600}#job-details-modal .more-modal__list .more-modal__details{padding-left:0}#job-details-modal .error-status-content{display:flex;min-width:0;height:100%;flex-direction:column;padding:0px 32px 32px}#job-details-modal .error-status-content__title{color:var(--error-text)}#job-details-modal .error-status-content .post-code{max-width:100%;overflow-x:auto}#job-details-modal .error-status-content .post-code code,#job-details-modal .error-status-content .post-code .hljs{overflow-wrap:anywhere;white-space:pre-wrap;word-break:break-word}#job-details-modal .canceled-status-content{padding:32px}
.AccessControlSyncJobTable{overflow:auto}.AccessControlSyncJobTable .policy-header{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.AccessControlSyncJobTable .policy-header-text h1{margin-bottom:8px;font-size:20px;font-weight:600}.AccessControlSyncJobTable .policy-header-text p{margin:0;color:rgba(63,67,80,.72)}.AccessControlSyncJobTable .policy-header .btn-primary{display:flex;align-items:center;padding:10px 16px;gap:8px}.AccessControlSyncJobTable .policy-header .btn-primary .icon{font-size:18px}.AccessControlSyncJobTable .job-table__access-control .job-table__table{max-height:400px;padding:0px;border:none}.AccessControlSyncJobTable .job-table__access-control .table>thead>tr>th,.AccessControlSyncJobTable .job-table__access-control .table>tbody>tr>th,.AccessControlSyncJobTable .job-table__access-control .table>tfoot>tr>th,.AccessControlSyncJobTable .job-table__access-control .table>thead>tr>td,.AccessControlSyncJobTable .job-table__access-control .table>tbody>tr>td,.AccessControlSyncJobTable .job-table__access-control .table>tfoot>tr>td{border-top:none;padding-block:10px}.AccessControlSyncJobTable .job-table__access-control .table>thead>tr>th{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);font-size:1em;font-weight:600}.AccessControlSyncJobTable .job-table__access-control .cancel-button-field{width:30px}.AccessControlSyncJobTable .job-table__access-control .table-row{min-height:40px;cursor:pointer}.AccessControlSyncJobTable .DataGrid_footer{border-bottom:0;color:rgba(var(--sys-center-channel-color-rgb), 0.56)}.AccessControlSyncJobTable .actions-column{justify-content:flex-end !important;text-align:right}
.Card{border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);transition:box-shadow .3s ease-in-out}.Card+.Card{margin-top:16px}.Card.expanded{box-shadow:0 8px 24px rgba(0,0,0,.12)}.Card:not(.expanded):hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);box-shadow:0 4px 6px rgba(0,0,0,.12);transition-duration:.15s}.Card.console{width:100%;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:2px;margin-bottom:20px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.Card.console .Card__header{display:flex;align-items:center;justify-content:space-between;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.Card.console .Card__header .text-top{font-size:16px;font-weight:600;line-height:24px}.Card.console .Card__header .text-bottom{margin-right:24px;font-size:14px;line-height:20px}.Card.console .Card__header .content-button{height:32px;padding:10px 16px;border:none;border-radius:4px;margin-left:auto;font-size:12px;font-weight:600;line-height:9.5px;white-space:nowrap}.Card.console .Card__header .content-button.primary{background:var(--sys-button-bg);color:var(--sys-button-color)}.Card.console .Card__header .Card__hr{display:none}.Card.console .Card__body{overflow:visible}.Card.console .Card__body.expanding{transition:none}.Card.console .Card__body.expanded{margin:28px 32px}.Card__header hr.Card__hr{border-color:rgba(var(--center-channel-color-rgb), 0.08);margin:0 12px}.Card__body{overflow:hidden;height:0;margin:0 12px}.Card__body.expanding{transition-duration:.3s;transition-property:height,margin;transition-timing-function:ease-in-out}.Card__body.expanded{margin:12px}.Card__body.expanded:not(.expanding){height:auto}@media screen and (max-width: 768px){.Card+.Card{margin-top:12px}}
.app__body .modal .channel-selector-modal .modal-header .GenericModal__header__text_container,.console__body .modal .channel-selector-modal .modal-header .GenericModal__header__text_container{margin-top:0}
.AccessControlPolicyChannelsList .Filter_content.Filter__show{width:320px}.AccessControlPolicyChannelsList .FilterList{width:auto}.AccessControlPolicyChannelsList .ChannelList__nameColumn{display:inline-flex;align-items:center}.AccessControlPolicyChannelsList .ChannelList__nameColumn span.channel-icon{margin-right:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader{display:flex;align-items:center;justify-content:flex-start;padding-left:16px;gap:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox{position:relative;display:inline-block;width:16px;height:16px;padding:0;border:1px solid var(--center-channel-color);border-radius:2px;appearance:none;background:none;cursor:pointer;transition:all .15s ease}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox>*{pointer-events:none}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:checked{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:checked::after{position:absolute;top:1px;left:5px;width:6px;height:10px;border:solid #fff;border-width:0 1.5px 1.5px 0;content:"";transform:rotate(45deg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:indeterminate{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:indeterminate::after{position:absolute;top:7px;left:3px;width:10px;height:2px;background-color:#fff;content:""}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:focus{box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.2);outline:none}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:hover:not(:disabled){border-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:disabled{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.48}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-text{letter-spacing:.02em}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .ChannelList__autoAddInfoIcon{margin-left:-6px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:16px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .ChannelList__autoAddInfoIcon:hover{color:rgba(var(--sys-center-channel-color-rgb), 0.72)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn{display:flex;align-items:center;justify-content:flex-start;padding-left:16px;gap:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox{position:relative;display:inline-block;width:16px;height:16px;padding:0;border:1px solid var(--center-channel-color);border-radius:2px;appearance:none;background:none;cursor:pointer;transition:all .15s ease}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox>*{pointer-events:none}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:checked{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:checked::after{position:absolute;top:1px;left:5px;width:6px;height:10px;border:solid #fff;border-width:0 1.5px 1.5px 0;content:"";transform:rotate(45deg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:focus{box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.2);outline:none}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:hover:not(:disabled){border-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:disabled{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.48}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .checkbox-label{line-height:16px;user-select:none}.AccessControlPolicyChannelsList .DataGrid{padding:0;background-color:rgba(var(--sys-white-rgb), 0.04)}.AccessControlPolicyChannelsList .DataGrid_search{border-bottom:none}.AccessControlPolicyChannelsList .DataGrid_searchBar{margin-left:0}.AccessControlPolicyChannelsList .DataGrid .DataGrid_rows .DataGrid_row{display:flex;min-height:40px;border-left:none;background-color:rgba(var(--sys-white-rgb), 0.04);cursor:pointer}.AccessControlPolicyChannelsList .DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:none;background-color:rgba(0,0,0,.05)}
.cel-editor{margin-bottom:24px}.cel-editor__masked-banner{display:flex;align-items:center;padding:10px 16px;border-radius:4px;margin-bottom:8px;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);font-size:13px;gap:8px;line-height:20px}.cel-editor__masked-banner .icon{color:var(--dnd-indicator);font-size:18px}.cel-editor__container{position:relative;display:flex;overflow:auto;height:auto;flex-direction:column;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin-bottom:8px;background:var(--center-channel-bg);overflow-y:auto}.cel-editor__container .policy-editor-placeholder{position:absolute;z-index:10;top:13px;left:30px;color:rgba(0,0,0,.4);font-family:monospace;font-size:12px;pointer-events:none;user-select:none;white-space:pre-wrap}.cel-editor__cursor-position{position:absolute;right:8px;border-radius:4px;color:var(--button-color);font-family:monospace;font-size:12px;pointer-events:none}.cel-editor__input{overflow:auto;width:100%;height:auto;min-height:120px;max-height:600px;flex-grow:0;padding:12px;border:1px solid var(--button-bg);border-radius:4px 4px 0 0;font-family:monospace;resize:vertical;transition:border-color .15s ease}.cel-editor__input:focus{outline:none}.cel-editor__input::placeholder{color:rgba(var(--center-channel-color-rgb), 0.56)}.cel-editor__input .policyEditor{outline:none}.cel-editor__container[data-status-color="var(--error-text)"] .cel-editor__input{border-color:var(--error-text)}.cel-editor__container[data-status-color="var(--online-indicator)"] .cel-editor__input{border-color:var(--online-indicator)}.cel-editor__container[data-status-color="var(--button-bg)"] .cel-editor__input{border-color:var(--button-bg)}.cel-editor__footer{display:flex;align-items:flex-start;justify-content:space-between;margin-top:8px}.cel-editor__footer .help-text-container{flex:1;padding-right:16px;color:var(--center-channel-color-72);font-size:12px}.cel-editor__actions{display:flex;align-items:center}.cel-editor__loading{display:flex;align-items:center}.cel-editor__loading i{margin-right:8px}.cel-editor__status-bar{display:flex;min-height:24px;align-items:center;justify-content:space-between;padding:0 8px;border-radius:0 0 4px 4px;color:var(--button-color);font-family:monospace;font-size:12px;transition:background-color .15s ease}.cel-editor__status-bar:not([data-validation-state=validated]):not([data-validation-state=error]):not([data-validation-state=validating]){cursor:pointer}.cel-editor__status-bar:not([data-validation-state=validated]):not([data-validation-state=error]):not([data-validation-state=validating]):hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.cel-editor__status-bar:not([data-validation-state=validated]):not([data-validation-state=error]):not([data-validation-state=validating]):active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.cel-editor__error-message{display:flex;align-items:center}.cel-editor__error-message .icon{margin-right:4px;font-size:14px}.cel-editor__error{display:flex;align-items:center;color:var(--button-color)}.cel-editor__status-message{display:flex;align-items:center}.cel-editor__status-message .icon{margin-right:4px;font-size:14px}.cel-editor__status-message .icon.icon-refresh{cursor:pointer}.cel-editor__status-message .icon.icon-refresh:hover{opacity:.8}.cel-editor__inline-validate-btn{padding:0;border:none;background:rgba(0,0,0,0);color:var(--button-color);cursor:pointer;font-size:12px;font-weight:600}.cel-editor__inline-validate-btn:hover{text-decoration:underline}.cel-editor__inline-validate-btn:disabled{cursor:not-allowed;opacity:.6}.cel-editor__inline-validate-btn .cel-editor__loading{display:flex;align-items:center}.cel-editor__inline-validate-btn .cel-editor__loading i{margin-right:4px;font-size:12px}.cel-editor__validate-btn{display:none}.cel-test-results-modal .modal-body{max-height:70vh;overflow-y:auto}.cel-test-results-modal .cel-test-attributes{padding:10px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-bottom:20px}.cel-test-results-modal .cel-test-attributes .cel-attribute-tag{display:inline-block;padding:4px 8px;border-radius:4px;margin:0 4px 4px 0;background:rgba(var(--center-channel-color-rgb), 0.08);font-size:12px}.cel-test-results-modal .cel-subjects-list .cel-subject-item{padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;margin-bottom:12px}.cel-test-results-modal .cel-subjects-list .cel-subject-item .cel-subject-header{margin-bottom:8px;font-weight:600}.cel-test-results-modal .cel-subjects-list .cel-subject-item .cel-subject-attributes{display:grid;gap:8px;grid-template-columns:repeat(auto-fill, minmax(200px, 1fr))}.cel-test-results-modal .cel-subjects-list .cel-subject-item .cel-subject-attributes .cel-subject-attribute .cel-attribute-key{margin-right:4px;font-weight:500}.cel-test-results-modal .cel-subjects-list .cel-subject-item .cel-subject-attributes .cel-subject-attribute .cel-attribute-value{color:rgba(var(--center-channel-color-rgb), 0.72)}.Card__body.expanded:has(.cel-editor){height:max-content !important}
.PolicyConfirmationModal .modal-body .enforce-toggle{margin-top:20px}.PolicyConfirmationModal .modal-body .enforce-toggle .enforce-checkbox-label{display:flex;align-items:center;color:#3d3c40;cursor:pointer}.PolicyConfirmationModal .modal-body .enforce-toggle .enforce-checkbox-label input[type=checkbox]{margin-right:8px;cursor:pointer}.PolicyConfirmationModal .modal-body .confirmation{margin-top:20px;color:#3d3c40;font-weight:600}.PolicyConfirmationModal .modal-footer .btn-cancel{padding:10px 16px;border:none;border-radius:4px;margin-right:10px;background:#f2f4f8;color:#3d3c40;font-size:14px;font-weight:600}.PolicyConfirmationModal .modal-footer .btn-cancel:hover{background:#e8eaed}.PolicyConfirmationModal .modal-footer .btn-apply{padding:10px 16px;border:none;border-radius:4px;background:#c74a4a;color:#fff;font-size:14px;font-weight:600}.PolicyConfirmationModal .modal-footer .btn-apply:hover{background:#b73535}.PolicyConfirmationModal .modal-footer .btn-save{padding:10px 16px;border:none;border-radius:4px;background:#166de0;color:#fff;font-size:14px;font-weight:600}.PolicyConfirmationModal .modal-footer .btn-save:hover{background:#0f5fc0}
.AccessControlPolicySettings .form-group{min-height:40px}.AccessControlPolicySettings .delete-policy .btn-primary:not(:disabled){background-color:var(--dnd-indicator)}.AccessControlPolicySettings .vertically-centered-label{padding-top:7px}.AccessControlPolicySettings .EditPolicy__error{display:flex;align-items:center;margin-left:12px;color:var(--error-text);font-size:14px}.AccessControlPolicySettings .EditPolicy__error i{margin-right:4px;font-size:16px}.AccessControlPolicySettings .admin-console__warning-notice{margin-bottom:16px}.AccessControlPolicySettings .admin-console__warning-notice h4{margin-bottom:0}.AccessControlPolicySettings .AccessControlPolicySettings__mixedChannelsNotice{margin-bottom:16px}.AccessControlPolicySettings .AccessControlPolicySettings__mixedChannelsNotice h4{margin-bottom:0}.AccessControlPolicySettings .EditPolicy__masked-values-warning{margin-top:4px}.AccessControlPolicySettings .EditPolicy__delete-masked-values-warning{margin:28px 28px 0}
.CloudFetchError{display:flex;flex-direction:column;align-items:center;padding:10px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color);text-align:center}.CloudFetchError__header{padding-bottom:10px;font-size:16px;line-height:24px}
.CloudInvoicePreview{top:15px;width:860px;height:1030px;border-radius:8px;margin:0 auto;overflow-y:hidden !important}.CloudInvoicePreview .modal-header{display:block;padding-bottom:0;border:none;background-color:#fff !important;color:#3f4350}.CloudInvoicePreview .modal-header .close{margin-top:auto;margin-bottom:auto;color:rgba(63,67,80,.75) !important}.CloudInvoicePreview .modal-header .modal-title{color:inherit;font-family:"Metropolis";font-size:22px;font-style:normal;font-weight:600}.CloudInvoicePreview .modal-header .subtitle{margin-top:10px;color:rgba(61,60,64,.75);font-family:"Metropolis";font-size:14px;font-style:normal}.CloudInvoicePreview .modal-open{overflow-y:hidden !important}.CloudInvoicePreview .modal{width:100%;max-width:100%;height:100%;margin:0 !important}.CloudInvoicePreview .modal-dialog{width:100%;max-width:100%;height:100%;margin:0 !important}.CloudInvoicePreview .modal-body{padding:0}.CloudInvoicePreview .modal-body .view-image__loading{background-color:#fff;color:#fff}.CloudInvoicePreview .modal-body .view-image__loading .fa{color:#3f4350}.CloudInvoicePreview .post-code{display:flex}.CloudInvoicePreview .post-code canvas{display:block;max-height:100%;padding-right:0;padding-left:0;margin-right:auto;margin-left:auto}
.BillingHistory__card{width:100%;height:"463px";border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.CloudBillingHistoryModal .CloudBillingHistoryModal__title{font-family:"Metropolis";font-size:22px;font-weight:semibold}.BillingHistory__cardHeader{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__cardHeaderText-top{font-size:16px;font-weight:600;line-height:24px}.BillingHistory__cardHeaderText-bottom{font-size:14px;line-height:20px}.BillingHistory__cardBody{padding:48px}.BillingHistory__noHistory{display:flex;flex-direction:column;align-items:center}.BillingHistory__noHistory-message{margin-top:24px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.BillingHistory__noHistory-link{margin-top:20px;color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.BillingHistory__noHistory-graphic{margin-top:28px}.BillingHistory__table{width:100%}.BillingHistory__table th,.BillingHistory__table td{padding:8px 12px}.BillingHistory__table-header{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);background:rgba(var(--sys-center-channel-color-rgb), 0.08);font-weight:600;line-height:16px}.BillingHistory__table-header:last-child{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__table-row{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__table-row:hover{cursor:pointer}.BillingHistory__table-row:nth-child(odd){background:rgba(var(--sys-center-channel-color-rgb), 0.04)}.BillingHistory__table-bottomDesc{margin-top:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.BillingHistory__table-headerTotal{text-align:left}.BillingHistory__table-total{font-weight:600;text-align:left}.BillingHistory__spinner{margin:auto;text-align:center}.BillingHistory__paymentStatus{color:var(--sys-online-indicator)}.BillingHistory__paymentStatus i{font-size:14.4px;line-height:17px}.BillingHistory__paymentStatus i::before{margin:0}.BillingHistory__paymentStatus span{margin-left:4px;font-weight:600}.BillingHistory__paymentStatus.failed{color:var(--sys-error-text)}.BillingHistory__paymentStatus.pending span{color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.BillingHistory__table-invoice a,.BillingHistory__table-invoice a:link,.BillingHistory__table-invoice a:visited,.BillingHistory__table-invoice a:hover,.BillingHistory__table-invoice a:focus,.BillingHistory__table-invoice a:active{text-decoration:none}.BillingHistory__paging{display:flex;align-items:center;justify-content:flex-end;margin-top:4px}.BillingHistory__paging>span{margin-right:8px}.BillingHistory__paging button{height:32px;padding:7px;border:none;border-radius:4px;margin-left:4px;background:none}.BillingHistory__paging button>i{font-size:18px}.BillingHistory__paging button>i::before{margin:0}.BillingHistory__paging button:disabled{opacity:.73}.BillingHistory__paging button:hover:not(:disabled){background:rgba(var(--sys-center-channel-color-rgb), 0.08)}
.style-button{width:fit-content;padding:8px 16px;border:none;border-radius:4px;background-color:var(--button-bg);color:var(--button-color);font-size:12px;font-weight:600;line-height:16px}.style-button span{color:var(--button-color)}.style-button i{color:var(--button-color);font-size:14px}.style-button:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg);color:var(--button-color);text-decoration:none}.style-link{display:inline-block;min-width:fit-content;border:none;background:none;color:var(--sidebar-bg)}.style-link:hover:not(.disabled){border:none;background:none;color:var(--sidebar-bg);text-decoration:underline}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.upgradeLink{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.upgradeLink:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.upgradeLink:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.upgradeLink:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.upgradeLink:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.upgradeLink i{display:flex;font-size:18px}
.BillingSummary{width:332px;padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;margin-left:20px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08)}.BillingSummary__noBillingHistory{display:flex;flex-direction:column;align-items:flex-start;justify-content:flex-start}.BillingSummary__noBillingHistory-title{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.BillingSummary__noBillingHistory-message{margin-top:8px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.BillingSummary__noBillingHistory-link{margin-top:16px;margin-bottom:24px;color:var(--sys-button-bg);font-size:12px;font-weight:600}.BillingSummary__lastInvoice{color:var(--sys-center-channel-color)}.BillingSummary__lastInvoice hr{border-color:rgba(var(--sys-center-channel-color-rgb), 0.32);margin:12px 0}.BillingSummary__lastInvoice-header{display:flex;align-items:center}.BillingSummary__lastInvoice-headerTitle{font-size:20px;font-weight:600;line-height:28px}.BillingSummary__lastInvoice-headerStatus{display:flex;align-items:center;margin-left:auto;font-size:12px;font-weight:600;line-height:16px}.BillingSummary__lastInvoice-headerStatus.paid{color:var(--sys-online-indicator)}.BillingSummary__lastInvoice-headerStatus.failed{color:var(--sys-error-text)}.BillingSummary__lastInvoice-headerStatus.pending{color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.BillingSummary__lastInvoice-headerStatus svg{width:16px;height:16px;margin-left:4px;font-size:14.4px}.BillingSummary__lastInvoice-headerStatus svg::before{margin:0 auto}.BillingSummary__lastInvoice-headerStatus span{margin-left:4px}.BillingSummary__lastInvoice-date{margin-top:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.BillingSummary__lastInvoice-productName{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.BillingSummary__lastInvoice-charge{display:flex;margin:12px 0}.BillingSummary__lastInvoice-charge.total{font-weight:600}.BillingSummary__lastInvoice-hasMoreItems{display:flex;align-items:center;color:#166de0}.BillingSummary__lastInvoice-hasMoreItems .BillingSummary__lastInvoice-chargeDescription:hover{cursor:pointer;text-decoration:underline}.BillingSummary__lastInvoice-chargeAmount{margin-left:auto}.BillingSummary__lastInvoice-partialCharges{color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.BillingSummary__lastInvoice-partialCharges+.BillingSummary__lastInvoice-charge{margin-top:4px}.BillingSummary__lastInvoice-download{margin-top:32px;margin-bottom:16px}.BillingSummary__lastInvoice-downloadButton{width:100%}.BillingSummary__lastInvoice-billingHistory{display:block;font-size:12px;font-weight:600;line-height:9.5px;text-align:center}
.PlanDetailsFeature{margin-top:12px;color:var(--sys-center-channel-color);line-height:16px}.PlanDetailsFeature i{font-size:14.4px}.PlanDetailsFeature i::before{margin:0}.PlanDetailsFeature span{margin-left:8px;font-size:12px}
.PlanDetails{width:568px;padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08)}.PlanDetails__top{display:flex;align-items:center}.PlanDetails__productName{color:var(--sys-center-channel-color);font-size:16px;font-weight:600;line-height:24px}.PlanDetails__userCount{display:block;margin-left:auto;color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:14px;font-weight:600;line-height:20px}.PlanDetails__viewPlansButton{display:block;margin-left:auto}.PlanDetails__planName{font-size:32px;font-weight:600;line-height:32px}.PlanDetails__teamAndChannelCount{margin-top:24px;color:var(--sys-center-channel-color);font-size:12px;font-weight:600;line-height:16px}.PlanDetails__description{display:flex;margin-top:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px;font-weight:normal;line-height:16px}.PlanDetails__description .PlanDetails__planDetailsName{font-size:12px;font-weight:600}.PlanDetails__description a{color:var(--sys-sidebar-text-active-border)}.PlanDetails__description a::before{content:" "}.PlanDetails__currentPlan{display:flex;align-items:center;margin-top:24px;color:var(--sys-online-indicator)}.PlanDetails__currentPlan i{font-size:18px;line-height:21px}.PlanDetails__currentPlan i::before{margin:0}.PlanDetails__currentPlan span{margin-left:8px;font-size:14px;font-weight:600;line-height:14px}.TrialBadge{padding:0 4px;border-radius:3px;margin-left:10px;background:var(--sys-online-indicator);color:#fff;text-transform:uppercase}.TrialBadge span{font-size:10px;font-weight:600;letter-spacing:.02em;line-height:16px}.RecurringIntervalBadge{display:inline-block;height:16px;margin-left:12px;text-transform:uppercase}.RecurringIntervalBadge span{position:relative;bottom:2px;color:rgba(var(--center-channel-text-rgb), 0.75);font-family:"Open Sans";font-size:10px;font-weight:600;letter-spacing:.02em;line-height:16px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.BillingSubscriptions .BillingSubscriptions__topWrapper{display:flex}.BillingSubscriptions .AlertBanner{margin-bottom:20px}.BillingSubscriptions__tooltip.tooltip{font-family:"Open Sans",sans-serif}.BillingSubscriptions__tooltip.tooltip.bottom{padding:10px 0}.BillingSubscriptions__tooltip.tooltip.in{opacity:1}.BillingSubscriptions__tooltip.tooltip.BillingSubscriptions__tooltip-left .tooltip-inner{left:40%}.BillingSubscriptions__tooltip.tooltip.BillingSubscriptions__tooltip-right .tooltip-inner{right:90%}.BillingSubscriptions__tooltip.tooltip .tooltip-inner{position:relative;min-width:337px;max-width:none;padding:24px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--sys-center-channel-bg);box-shadow:0 12px 32px rgba(0,0,0,.12);color:var(--sys-center-channel-color);opacity:1;text-align:left}.BillingSubscriptions__tooltip.tooltip .tooltip-arrow{z-index:2;border-width:0 11px 11px;border-bottom-color:rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingSubscriptions__tooltip.tooltip .tooltip-arrow::before{position:relative;top:-10px;left:-11px;display:block;width:0;height:0;border:11px solid rgba(0,0,0,0);border-bottom-color:var(--sys-center-channel-bg);content:""}.UpgradeMattermostCloud{text-align:center}.UpgradeMattermostCloud__image{flex:0 0 auto}.UpgradeMattermostCloud__title{align-self:flex-start;margin-top:16px;color:var(--sys-center-channel-color);font-size:16px;font-weight:600;line-height:24px;text-align:left}.UpgradeMattermostCloud__description{margin-top:12px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px;text-align:left}.UpgradeMattermostCloud__upgradeButton{width:100%;margin-top:16px}.PrivateCloudCard{padding:32px 54px 18px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;margin-top:20px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);display:flex}.PrivateCloudCard .UpgradeMattermostCloud__upgradeButton{max-width:200px}.PrivateCloudCard__text{max-width:563px;flex-grow:1;color:var(--sys-center-channel-color)}.PrivateCloudCard__text-title{font-size:16px;font-weight:600;line-height:24px}.PrivateCloudCard__text-description{margin-top:12px;font-size:14px;line-height:20px}.PrivateCloudCard__image{flex:0 0 173px;margin-left:85px}.PrivateCloudCard__actionButton{display:flex;align-items:center;justify-content:center;margin-top:16px}.cancelSubscriptionSection{display:flex;padding:12px 54px 18px 32px;margin-top:20px}.cancelSubscriptionSection__text{flex-grow:1;color:var(--sys-center-channel-color)}.cancelSubscriptionSection__text-title{font-size:12px;font-weight:600;line-height:16px}.cancelSubscriptionSection__text-description{margin-top:12px;font-size:12px;font-weight:400;line-height:16px}.cancelSubscriptionSection__contactUs{display:block;margin-top:16px}
.CompanyInfoDisplay{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.CompanyInfoDisplay__header{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.CompanyInfoDisplay__headerText-top{font-size:16px;font-weight:600;line-height:24px}.CompanyInfoDisplay__headerText-bottom{font-size:14px;line-height:20px}.CompanyInfoDisplay__addInfo{margin-left:auto}.CompanyInfoDisplay__addInfoButton{align-items:center}.CompanyInfoDisplay__noCompanyInfo{display:flex;flex-direction:column;align-items:center;padding:48px}.CompanyInfoDisplay__noCompanyInfo-message{margin-top:24px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.CompanyInfoDisplay__noCompanyInfo-link{margin-top:20px;color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.CompanyInfoDisplay__companyInfo{display:flex;padding:28px 45px 30px 32px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.CompanyInfoDisplay__companyInfo-name{font-weight:600}.CompanyInfoDisplay__companyInfo-addressTitle{margin-top:16px;font-weight:600}.CompanyInfoDisplay__companyInfo-address>div{margin-top:4px}.CompanyInfoDisplay__companyInfo-edit{margin-left:auto}.CompanyInfoDisplay__companyInfo-editButton{padding:2px;border-radius:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:18px}.CompanyInfoDisplay__companyInfo-editButton:hover,.CompanyInfoDisplay__companyInfo-editButton:focus{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.75);text-decoration:none}
.CompanyInfoEdit__card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;margin-top:20px;background-color:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);isolation:isolate}.CompanyInfoEdit__card .checkbox{margin-top:0;margin-bottom:24px}.CompanyInfoEdit__card .checkbox input{width:16px;height:16px;margin-top:2px}.CompanyInfoEdit__card .checkbox span{padding-left:4px}.CompanyInfoEdit__card .form-row{display:flex;width:100%;margin-bottom:24px}.CompanyInfoEdit__card .form-row-third-1{width:66%;margin-right:16px}.CompanyInfoEdit__card .form-row-third-1 .DropdownInput{z-index:99999;margin-top:0}.CompanyInfoEdit__card .form-row-third-2{width:34%}.CompanyInfoEdit__card .section-title{margin-bottom:24px;color:var(--sys-center-channel-text);font-size:16px;font-weight:600;text-align:left}.CompanyInfoEdit__card .section-title:not(:first-child){font-size:14px;line-height:20px}.CompanyInfoEdit__card .DropdownInput{position:relative;z-index:999999;height:36px;margin-bottom:24px}.CompanyInfoEdit__card .DropdownInput .DropDown__control{min-height:0}.CompanyInfoEdit__card .full-width{width:100%}.CompanyInfoEdit__card input{font-size:14px}.CompanyInfoEdit__card .Input_fieldset{height:40px;padding:2px 1px;background:var(--sys-center-channel-bg)}.CompanyInfoEdit__card .Input_fieldset .Input_wrapper{margin:0}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___legend>label{margin-left:11px}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset:focus-within{padding-top:2px;box-shadow:inset 0 0 0 2px var(--sys-button-bg);color:var(--button-bg)}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___error{padding-top:1px;padding-bottom:1px;box-shadow:inset 0 0 0 1px var(--sys-error-text);color:var(--error-text)}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___error:focus-within{box-shadow:inset 0 0 0 2px var(--sys-error-text);color:var(--error-text)}.CompanyInfoEdit__card .Input_fieldset .Input{height:32px}.CompanyInfoEdit__card .Input_fieldset .Input::placeholder{color:var(--sys-center-channel-color);opacity:.73}.CompanyInfoEdit__form{max-width:480px}.CompanyInfoEdit__companyInfo-addressTitle{margin-top:16px;font-weight:600}.CompanyInfoEdit__companyInfo-address>div{margin-top:4px}
.ClassificationColorInput{position:relative;display:inline-block;width:100%;max-width:200px}.ClassificationColorInput__control{display:flex;height:34px;box-sizing:border-box;align-items:center;padding:0 10px 0 8px;border:none;border-radius:0;background:rgba(0,0,0,0);gap:8px}.ClassificationColorInput__control:focus-within{background:rgba(var(--button-bg-rgb), 0.06)}.ClassificationColorInput__swatch{display:block;width:20px;height:20px;flex-shrink:0;padding:0;border:1px solid rgba(0,0,0,0);border-radius:2px;background:rgba(0,0,0,0);cursor:pointer}.ClassificationColorInput__swatch:disabled{cursor:not-allowed;opacity:.5}.ClassificationColorInput__swatch:focus-visible{outline:2px solid var(--button-bg);outline-offset:1px}.ClassificationColorInput__hex{min-width:0;height:100%;flex:1 1 auto;padding:0;border:none;background:rgba(0,0,0,0);color:var(--center-channel-color);font-size:14px;line-height:20px;outline:none;text-transform:uppercase}.ClassificationColorInput__hex:disabled{cursor:not-allowed;opacity:.6}.ClassificationColorInput__hex::placeholder{color:rgba(var(--center-channel-color-rgb), 0.48)}.ClassificationColorInput__popover{position:absolute;z-index:10000;top:calc(100% + 4px);left:0}
.DataRetentionSettings .JobSelectTime{display:inline-block;width:80px;margin:-10px 8px -10px}.DataRetentionSettings span.JobSelectedtime{margin:0 8px}.DataRetentionSettings .datagrid-menuwrapper{z-index:999999}.DataRetentionSettings a.EditJobTime{font-weight:600;opacity:1}.DataRetentionSettings .actionIcon{flex-grow:.15}.DataRetentionSettings input:-webkit-autofill,.DataRetentionSettings input:-webkit-autofill:hover,.DataRetentionSettings input:-webkit-autofill:focus,.DataRetentionSettings input:-webkit-autofill:active{-webkit-box-shadow:0 0 0 30px var(--sys-center-channel-bg) inset}
.PolicyChannelsList .ChannelList__nameColumn{display:inline-flex;align-items:center;justify-content:center}.PolicyChannelsList .ChannelList__nameColumn span.channel-icon{margin:3px 8px 0 0}.PolicyChannelsList .Filter_content.Filter__show{width:320px}.PolicyChannelsList .FilterList{width:auto}
.PolicyTeamsList .TeamList__nameColumn{display:inline-flex;align-items:center;justify-content:center;padding:20px 0}.PolicyTeamsList .TeamList__nameColumn .TeamList__lowerOpacity .TeamIcon{background-color:rgba(var(--sys-center-channel-color-rgb), 0.16)}.PolicyTeamsList .TeamList__nameColumn .TeamList__nameText{padding-left:12px}.PolicyTeamsList .TeamList__actionColumn{display:inline-flex;align-items:center;justify-content:flex-end}
.DropdownInput.hybrid_container{z-index:999999;margin-top:20px}.DropdownInput.hybrid_container .Input_wrapper{padding:0;margin:0}.DropdownInput.hybrid_container .Input_wrapper.input_hybrid_wrapper{display:inline-block;flex-grow:1;transition:max-width .1s ease-out}.DropdownInput.hybrid_container .Input_wrapper.input_hybrid_wrapper.showInput{transition:max-width .1s ease-in}.DropdownInput.hybrid_container .Input_wrapper.dropdown_hybrid_wrapper{display:inline-block}.DropdownInput.hybrid_container .Input_wrapper.dropdown_hybrid_wrapper.showInput{float:right;transition:width .1s ease-out}.DropdownInput.hybrid_container .Input{font-size:14px;line-height:20px}.DropdownInput.hybrid_container .Input.Input___focus .a11y--focused{box-shadow:none}.DropdownInput.hybrid_container .Input_fieldset{position:relative;display:flex;padding:0}.DropdownInput.hybrid_container .Input_legend{position:absolute;z-index:1;top:-8px;width:auto;padding:0 5px;border-bottom:none;margin-bottom:0;margin-left:8px;font-size:10px}.DropdownInput.hybrid_container .DropDown__menu{z-index:1000000;margin-top:2px}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer{margin-right:8px}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer i::before{margin:0}.DropdownInput.hybrid_container .DropdownInput__option>div{z-index:999999;padding:10px 24px;cursor:pointer;line-height:16px}.DropdownInput.hybrid_container .DropdownInput__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.DropdownInput.hybrid_container .DropdownInput__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.DropdownInput.hybrid_container .Input_fieldset:focus-within{border-width:2px;box-shadow:none}.DropdownInput.hybrid_container .Input.form-control{height:40px;border:none;border-radius:4px 0 0 4px;border-right:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.DropdownInput.hybrid_container .Input.form-control::-webkit-outer-spin-button,.DropdownInput.hybrid_container .Input.form-control::-webkit-inner-spin-button{margin:0;-webkit-appearance:none}.DropdownInput.hybrid_container .Input.form-control[type=number]{-moz-appearance:textfield}.DropdownInput.hybrid_container .Input.form-control:focus{border-right:1px solid rgba(var(--center-channel-color-rgb), 0.16)}
.CustomPolicy__fields{width:100%}@media screen and (min-width: 960px){.CustomPolicy__fields{width:50%}}.CustomPolicy__fields .DropdownInput .Input.form-control{padding:6px 12px}.CustomPolicy__fields i.icon.icon-infinity.option-icon{vertical-align:middle}.CustomPolicy__fields .Input{color:var(--sys-center-channel-color)}.CustomPolicy__fields .Input_wrapper,.CustomPolicy__fields .Input___info{color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.CustomPolicy__fields .Input::placeholder{color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.CustomPolicy__fields .Input_fieldset{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.CustomPolicy__fields .Input_fieldset:hover{border-color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.CustomPolicy__fields .Input_fieldset:focus-within{border-color:var(--sys-button-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg)}.CustomPolicy__fields .Input_fieldset:focus-within .Input_legend{color:var(--sys-button-bg)}.CustomPolicy__fields .Input_legend{background-color:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.CustomPolicy__error{display:flex;align-items:center;color:var(--sys-error-text);font-size:12px;line-height:16px}.CustomPolicy__error i{margin-right:4px;font-size:14.4px}
.global_policy{width:100%}@media screen and (min-width: 960px){.global_policy{width:50%}}.global_policy .Input.form-control{padding:6px 12px}.global_policy i.icon.icon-infinity.option-icon{vertical-align:middle}.global_policy .Input{color:var(--sys-center-channel-color)}.global_policy .Input_wrapper,.global_policy .Input___info{color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.global_policy .Input::placeholder{color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.global_policy .Input_fieldset{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.global_policy .Input_fieldset:hover{border-color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.global_policy .Input_fieldset:focus-within{border-color:var(--sys-button-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg)}.global_policy .Input_fieldset:focus-within .Input_legend{color:var(--sys-button-bg)}.global_policy .Input_legend{background-color:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.global_policy .alert.alert-warning{margin-top:10px}.CustomPolicy__error{display:flex;align-items:center;color:var(--sys-error-text);font-size:12px;line-height:16px}.CustomPolicy__error i{margin-right:4px;font-size:14.4px}
.migrations-table__table{overflow:auto;width:100%;min-height:100px;max-height:240px;padding:5px;border:gray;margin:20px 0 10px;background-color:#fff}.migrations-table .table>thead>tr>th,.migrations-table .table>tbody>tr>th,.migrations-table .table>tfoot>tr>th,.migrations-table .table>thead>tr>td,.migrations-table .table>tbody>tr>td,.migrations-table .table>tfoot>tr>td{border-top:none}.migrations-table .table>thead>tr>th{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.migrations-table .help-text{padding:10px 16px;background:rgba(var(--sys-center-channel-color-rgb), 0.04);color:var(--sys-center-channel-color)}
.FeatureDiscovery{display:grid;padding:20px;border-radius:8px;background:#fff;box-shadow:0 2px 3px rgba(0,0,0,.08);font-family:Open Sans;font-style:normal;font-weight:normal;grid-template-columns:repeat(auto-fit, minmax(440px, 1fr))}.FeatureDiscovery_imageWrapper{display:flex;align-items:center;justify-content:center}.FeatureDiscovery_copyWrapper,.FeatureDiscovery_imageWrapper{padding:20px 0 20px 20px;grid-template-columns:repeat(2, 1fr)}.FeatureDiscovery_image{height:220px}.FeatureDiscovery_title{padding-bottom:16px;font-family:Metropolis,sans-serif !important;font-size:20px;line-height:28px}.FeatureDiscovery_copy{padding-bottom:24px;font-size:14px;line-height:20px}.purchase-card{display:flex;gap:8px}.purchase-card .btn{margin-left:0}
.AutoTranslationFeatureDiscovery .FeatureDiscovery{all:unset;display:grid;align-items:center;font-family:"Open Sans",sans-serif;font-style:normal;font-weight:normal;gap:24px;grid-template-columns:1fr auto}.AutoTranslationFeatureDiscovery .FeatureDiscovery .FeatureDiscovery_copyWrapper{padding:0}.AutoTranslationFeatureDiscovery .FeatureDiscovery .FeatureDiscovery_imageWrapper{padding:8px 32px}.AutoTranslationFeatureDiscovery .FeatureDiscovery .SkuTag.FeatureDiscovery_tag{margin-bottom:8px}.AutoTranslationFeatureDiscovery .FeatureDiscovery .FeatureDiscovery_title{padding-bottom:8px}.AutoTranslationTag{display:flex;width:fit-content}
.AdminPanel{padding:0;border:solid 1px rgba(var(--center-channel-color-rgb), 0.12);border-radius:var(--radius-s);margin:2em 0 1em;background-color:var(--center-channel-bg);box-shadow:var(--elevation-1);font-size:.95em}.AdminPanel .AdminPanel__content{padding:10px 20px 20px}.AdminPanel .AdminPanel__table{width:100%}.AdminPanel .AdminPanel__table th{border-bottom:solid 1px alpha-color(rgb(0, 0, 0), 0.1)}.AdminPanel .AdminPanel__table td,.AdminPanel .AdminPanel__table th{padding:6px 20px}.AdminPanel .AdminPanel__table td:first-child,.AdminPanel .AdminPanel__table th:first-child{padding-left:20px}.AdminPanel .header{display:flex;flex-direction:row;align-items:center;justify-content:space-between;padding:20px;border-radius:var(--radius-s) var(--radius-s) 0 0;background:#fff}.AdminPanel .header h3{padding:0;margin:4px 0 !important;font-size:18px;font-weight:600}.AdminPanel .header .button{align-self:flex-end;margin-left:10px}.AdminPanel .header .button svg{transform:rotate(0deg);transition:transform 300ms}.AdminPanel.closed .header .button svg{transform:rotate(90deg);transition:transform 300ms}.AdminPanelTogglable .AdminPanelTogglableContent{display:grid;grid-template-rows:1fr;transition:all .4s ease-in-out 0s}.AdminPanelTogglable.closed .AdminPanelTogglableContent{grid-template-rows:0fr}.AdminPanelTogglable .AdminPanelTogglableContent .AdminPanelTogglableContentInner{overflow:hidden}
.IPFilteringAddOrEditModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:12px;margin:auto;transform:translate(-50%, -50%) !important}.IPFilteringAddOrEditModal .modal-content{border-radius:12px}.IPFilteringAddOrEditModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-right:32px;padding-bottom:0;padding-left:32px;border:0;border-radius:12px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.IPFilteringAddOrEditModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.IPFilteringAddOrEditModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.IPFilteringAddOrEditModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.IPFilteringAddOrEditModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.IPFilteringAddOrEditModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice{display:flex;max-width:536px;height:52px;border:1px rgba(87,158,255,.16) solid;border-radius:4px;background:rgba(87,158,255,.08)}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content{display:flex;width:536px;height:52px;padding:16px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;gap:12px;line-height:20px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content span{display:flex;height:20px;align-items:center;line-height:20px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content span svg{width:20px;height:20px;margin-right:12px;fill:#5d89ea}.IPFilteringAddOrEditModal .modal-body .inputs{color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.IPFilteringAddOrEditModal .modal-body .inputs>div{margin-top:24px}.IPFilteringAddOrEditModal .modal-body .inputs>div .Input_container{margin-top:8px}.IPFilteringAddOrEditModal .modal-body .inputs>div input{font-weight:normal}.IPFilteringAddOrEditModal .modal-body .inputs>p{margin-top:8px;font-weight:400}.IPFilteringAddOrEditModal .modal-body .buttons{margin-top:32px;text-align:right}.IPFilteringAddOrEditModal .modal-footer{padding:24px 32px;border-radius:12px;border-top:none;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}
.DeleteConfirmationModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:12px;margin:auto;transform:translate(-50%, -50%) !important}.DeleteConfirmationModal .modal-content{border-radius:12px}.DeleteConfirmationModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;border-radius:12px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.DeleteConfirmationModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.DeleteConfirmationModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.DeleteConfirmationModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.DeleteConfirmationModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.DeleteConfirmationModal .modal-body{overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px}.DeleteConfirmationModal .modal-footer{padding:24px 32px;border-radius:12px;border-top:none;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}
.EditSection{width:920px;height:auto;max-height:100%;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background:var(--center-channel-bg);box-shadow:0 2px 3px 0 rgba(0,0,0,.08)}.EditSection .TableSectionContent{display:inline-flex;width:100%;flex-direction:column;padding:20px}.EditSection .TableSectionContent .Table{display:flex;flex-direction:column;align-items:flex-start;align-self:stretch;justify-content:flex-start}.EditSection .TableSectionContent .Table .HeaderRow{display:flex;align-items:center;align-self:stretch;padding:10px 12px;border-bottom:1px solid var(--center-channel-color-16, rgba(63, 67, 80, 0.16));background-color:#f5f5f5;font-family:"Open Sans";font-size:14px;font-weight:600;gap:10px;line-height:20px}.EditSection .TableSectionContent .Table .HeaderRow .FilterName,.EditSection .TableSectionContent .Table .HeaderRow .IpAddressRange{color:#3f4350;font-family:"Open Sans";font-size:14px;line-height:20px;word-wrap:break-word}.EditSection .TableSectionContent .Table .HeaderRow .FilterName{width:291px;font-weight:600}.EditSection .TableSectionContent .Table .HeaderRow .IpAddressRange{flex:1 1 0}.EditSection .TableSectionContent .Table .Row{display:inline-flex;height:40px;align-items:center;align-self:stretch;justify-content:flex-start;padding:10px 12px;border-bottom:1px solid var(--center-channel-color-8, rgba(63, 67, 80, 0.08));background:#fff;gap:10px}.EditSection .TableSectionContent .Table .Row .FilterName,.EditSection .TableSectionContent .Table .Row .IpAddressRange{color:#3f4350;font-family:"Open Sans";font-size:14px;line-height:20px;word-wrap:break-word}.EditSection .TableSectionContent .Table .Row .FilterName{width:291px}.EditSection .TableSectionContent .Table .Row .IpAddressRange{flex:1 1 0}.EditSection .TableSectionContent .Table .Row .Actions{display:flex;align-items:center;justify-content:center}.EditSection .TableSectionContent .Table .Row .Actions>div{display:flex;align-items:center;justify-content:center;padding:6px;border-radius:4px}.EditSection .TableSectionContent .Table .Row .Actions>div:hover{background:var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.EditSection .TableSectionContent .Table .Row .Actions>div.edit{color:var(--center-channel-color-72, rgba(63, 67, 80, 0.72))}.EditSection .TableSectionContent .Table .Row .Actions>div.delete{color:var(--error-text, rgb(210, 75, 78))}.EditSection .NoFilters{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:32px 20px}.EditSection .NoFilters .Illustration{margin:16px 0}.EditSection .NoFilters .Title{margin-bottom:8px;color:var(--center-channel-color, #3f4350);font-family:Metropolis;font-size:20px;font-style:normal;font-weight:600;line-height:28px;text-align:center}.EditSection .NoFilters .Subtitle{max-width:320px;margin-bottom:8px;color:var(--center-channel-color-72, rgba(63, 67, 80, 0.72));font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}.EditSection .NoFilters .Subtitle .btn-primary{margin-top:16px}.EditSection .NoFilters .Subtitle .btn-primary:hover{cursor:pointer}.EditSection .AllowedIPAddressesSection{display:inline-flex;width:100%;flex-direction:column;align-items:flex-start;justify-content:flex-start}.EditSection .AllowedIPAddressesSection .SectionHeaderContent{display:flex;flex-direction:column;align-items:flex-start;align-self:stretch;justify-content:flex-start;padding:24px 32px;border-bottom:1px solid rgba(63,67,80,.12);gap:24px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent{display:inline-flex;align-items:flex-start;align-self:stretch;justify-content:flex-start;gap:32px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:center}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle .Title{color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:600;line-height:24px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle .Subtitle{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .AddIPFilterButton{display:inline-flex;flex-direction:column;align-items:flex-end;justify-content:flex-start;border:none;background:none;gap:16px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .AddIPFilterButton .Button{display:flex;flex-direction:column;align-items:center;justify-content:flex-start;padding:10px 16px;border:none;border-radius:4px;background:#1c58d9;color:#fff;gap:10px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel{display:inline-flex;width:856px;justify-content:flex-start;padding:16px;border:1px solid var(--error-text-16, rgba(210, 75, 78, 0.16));border-radius:4px;background:var(--error-text-8, rgba(210, 75, 78, 0.08));gap:12px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Icon{color:var(--error-text, #d24b4e)}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding-right:24px;gap:8px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Title{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Body{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Button{display:inline;height:16px;padding:0;padding-left:2px;background:none;color:var(--button-bg, rgb(28, 88, 217));font-size:14px;font-weight:600;line-height:20px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Button:hover{cursor:pointer}
.SaveConfirmationModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:12px;margin:auto;transform:translate(-50%, -50%) !important}.SaveConfirmationModal .modal-content{border-radius:12px}.SaveConfirmationModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;border-radius:12px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.SaveConfirmationModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.SaveConfirmationModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.SaveConfirmationModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.SaveConfirmationModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.SaveConfirmationModal .modal-body{overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px}.SaveConfirmationModal .modal-body .disclaimer{display:inline-flex;width:536px;height:120px;align-items:flex-start;justify-content:flex-start;padding:16px;border:1px solid rgba(87,158,255,.16);border-radius:4px;margin-top:32px;background:rgba(87,158,255,.08);gap:12px}.SaveConfirmationModal .modal-body .disclaimer .Icon{display:flex;align-items:center;justify-content:flex-start;gap:10px}.SaveConfirmationModal .modal-body .disclaimer .Icon svg{width:20px;height:20px;fill:var(--sidebar-text-active-border, rgb(93, 137, 234))}.SaveConfirmationModal .modal-body .disclaimer .Body{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding-right:24px;gap:8px}.SaveConfirmationModal .modal-body .disclaimer .Body .Title{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px;word-wrap:break-word}.SaveConfirmationModal .modal-body .disclaimer .Body .Subtitle{color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.SaveConfirmationModal .modal-footer{padding:24px 32px;border-radius:12px;border-top:none;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}
.IPFiltering{height:100%}.IPFiltering .admin-console-save .btn.btn-primary:disabled{color:rgba(var(--center-channel-color-rgb), 0.32) !important}.IPFiltering .MainPanel{display:flex;height:100%;flex-direction:column;align-items:flex-start;padding:20px;gap:20px}.IPFiltering .MainPanel .EnableSectionContent{display:inline-flex;width:920px;height:92px;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding:24px 32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--center-channel-bg);box-shadow:0 2px 3px 0 rgba(0,0,0,.08);gap:24px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent{display:inline-flex;align-items:flex-start;align-self:stretch;justify-content:flex-start;gap:32px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle{flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:center;gap:24px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle .Title{color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:600;line-height:24px;word-wrap:break-word}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle .Subtitle{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .SwitchSelector{width:32px;height:20px;flex-shrink:0}.IPFiltering .error-message{display:flex;align-items:center;justify-content:center;color:var(--error-text, #d24b4e);font-size:14px;line-height:20px}.IPFiltering .error-message>svg{margin-right:7px;margin-left:7px}.IPFiltering .error-message .saving-message-description{margin-left:16px;color:rgba(var(--center-channel-color-rgb), 0.72) !important}
.ldap-wizard-wrapper{background-color:rgba(var(--center-channel-color-rgb), 0.04)}.ldap-wizard-wrapper .ldap-wizard-content-wrapper{display:flex;overflow:hidden;flex-grow:1}.ldap-wizard-wrapper .ldap-wizard-content-wrapper .config-section{border-color:rgba(var(--center-channel-color-rgb), 0.12);border-radius:8px;margin-top:32px}.ldap-wizard-wrapper .ldap-wizard-content-wrapper .config-section .section-body{padding:32px 48px 48px}.ldap-wizard-wrapper .ldap-wizard-content-wrapper .config-section .section-body .section-header{padding:48px 0 0}.ldap-wizard-wrapper .ldap-wizard-content-wrapper .config-section .custom-section-body{padding:32px 0 0}.ldap-wizard-wrapper .ldap-wizard-content-wrapper .config-section:first-child{margin-top:0}.ldap-wizard-wrapper .admin-console__content{padding-top:20px}.ldap-wizard-wrapper .ldap-wizard-sidebar{display:flex;flex-direction:column;padding:40px 52px;gap:8px}.ldap-wizard-wrapper .ldap-wizard-sidebar .ldap-wizard-sidebar-header{display:flex;padding:0 0 8px 6px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;text-transform:uppercase}.ldap-wizard-wrapper .ldap-wizard-sidebar .ldap-wizard-sidebar-item{padding:8px 12px;border:none;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-weight:600;text-align:left;transition:background-color .2s ease}.ldap-wizard-wrapper .ldap-wizard-sidebar .ldap-wizard-sidebar-item:hover:not(.ldap-wizard-sidebar-item--active){background-color:rgba(var(--center-channel-color-rgb), 0.04)}.ldap-wizard-wrapper .ldap-wizard-sidebar .ldap-wizard-sidebar-item--active{background-color:rgba(var(--button-bg-rgb), 0.04);color:var(--button-bg)}.ldap-wizard-wrapper .section-header{display:flex;flex-direction:column;padding:48px 48px 0;border-bottom:0;gap:10px}.ldap-wizard-wrapper .section-header .section-title{font-family:Metropolis;font-size:22px;line-height:28px}.ldap-wizard-wrapper .section-header .section-subtitle{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:Metropolis;font-size:16px;line-height:24px}.ldap-wizard-wrapper .ldap-expandable-section{margin:20px 0}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-section-header{display:flex;align-items:center;gap:8px}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-section-toggle{padding:4px 0;border:none;background:none;color:var(--button-bg);font-weight:600}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-section-toggle:hover{text-decoration:underline}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-arrow{color:var(--button-bg);transition:transform .2s ease}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-arrow.open{transform:rotate(90deg)}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-section-content{overflow:hidden;max-height:0;padding-left:0;margin-top:0;opacity:0;transition:max-height .3s ease-out,opacity .2s ease-out,margin-top .3s ease-out}.ldap-wizard-wrapper .ldap-expandable-section .ldap-expandable-section-content.expanded{max-height:800px;margin-top:20px;opacity:1}.ldap-wizard-wrapper .ldap-help-text-more-info{padding:0;border:none;background:none;color:var(--button-bg);cursor:pointer;text-decoration:underline}.tooltipContainer.ldap-help-text-hover-tooltip{max-width:400px;text-align:left;white-space:pre-line}.ldap-text-setting{position:relative}.ldap-text-setting .filter-icon{position:absolute;top:10px;right:36px;cursor:pointer;font-size:16px;pointer-events:all}.ldap-text-setting .filter-iconsuccess{color:rgba(var(--semantic-color-success), 1)}.ldap-text-setting .filter-iconwarning{color:rgba(var(--semantic-color-warning), 1)}.ldap-text-setting .filter-iconerror{color:rgba(var(--semantic-color-danger), 1)}
.EnterpriseEditionRightPannel .svg-image{text-align:center}.EnterpriseEditionRightPannel .svg-image svg{margin:0 auto 24px auto}.EnterpriseEditionRightPannel .upgrade-title{margin-bottom:12px;color:#3f4350;font-family:Metropolis,sans-serif;font-size:16px;font-weight:700;line-height:24px}.EnterpriseEditionRightPannel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.EnterpriseEditionRightPannel .advantages-list .item{margin:10px 0}.EnterpriseEditionRightPannel .advantages-list .item i{margin-right:5px}.EnterpriseEditionRightPannel button{width:100%;margin:5px auto}.EnterpriseEditionRightPannel .purchase_buttons{margin-top:20px}.EnterpriseEditionRightPannel .purchase_buttons .btn-primary{margin-bottom:8px}.EnterpriseEditionRightPannel .purchase_buttons .trial-btn{width:100%;margin-left:0px}.EnterpriseEditionRightPannel .upgrade-error{margin-top:10px}.EnterpriseEditionLeftPanel__Grid{display:flex}.EnterpriseEditionLeftPanel__Header{display:flex;align-items:center;justify-content:space-between;gap:8px}.EnterpriseEditionLeftPanel__Title{display:flex;align-items:center;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:18px;font-weight:600;gap:8px}.EnterpriseEditionLeftPanel__Subtitle{margin-top:20px;font-size:14px}.EnterpriseEditionLeftPanel .pre-title{margin-bottom:10px;color:rgba(63,67,80,.75) !important;font-size:12px;font-weight:600;line-height:16px}.EnterpriseEditionLeftPanel .license-notices{font-size:12px}.EnterpriseEditionLeftPanel .license-notices p{margin-bottom:0px}.EnterpriseEditionLeftPanel .licenseInformation{padding:24px;border:1px solid rgba(63,67,80,.16);border-radius:4px;margin:24px 0}.EnterpriseEditionLeftPanel .licenseInformation__Header{display:flex;align-items:center;justify-content:space-between;font-size:14px;font-weight:700;gap:8px;line-height:24px}.EnterpriseEditionLeftPanel .licenseInformation__Title{display:inline-block;color:#3f4350;font-family:"Metropolis",sans-serif;font-size:16px;font-weight:700}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element{margin:15px 0;font-family:"Open Sans",sans-serif;font-size:14px;line-height:20px}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend{display:inline-block;min-width:210px;color:rgba(var(--secondary-blue-rgb), 0.75);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend--warning-over-seats-purchased{color:var(--warning-text)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend--over-seats-purchased{color:var(--error-text)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value{margin-left:10px;color:var(--secondary-blue)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value--warning-over-seats-purchased{color:var(--warning-text);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value--over-seats-purchased{color:var(--error-text);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days{margin-left:8px;font-size:14px;font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days-warning{color:var(--sys-away-indicator)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days-danger{color:var(--dnd-indicator)}.EnterpriseEditionLeftPanel .licenseInformation #remove-button{padding:0;border:none !important;margin:10px 0;background:none !important;color:var(--error-text);font-weight:700}.EnterpriseEditionLeftPanel .licenseInformation #remove-button:hover{text-decoration:underline}.EnterpriseEditionLeftPanel .licenseInformation #remove-button:focus,.EnterpriseEditionLeftPanel .licenseInformation #remove-button:focus-visible{outline:none !important}.EnterpriseEditionLeftPanel .single-channel-guest-limit-reached{display:inline-flex;align-items:center;margin-left:4px;cursor:pointer;gap:4px}.EnterpriseEditionLeftPanel .have-license-section{margin:24px 0}.EnterpriseEditionLeftPanel .have-license-section .have-license-title{margin:0 0 4px 0;font-family:"Metropolis",sans-serif;font-size:16px;line-height:24px}.single-channel-guest-license-tooltip{max-width:300px}
.ConfirmLicenseRemovalModal .modal-header button.close span{color:rgba(63,67,80,.75) !important}.ConfirmLicenseRemovalModal .modal-body{padding-top:0 !important;padding-bottom:40px !important}.ConfirmLicenseRemovalModal .content-body{display:flex;flex-direction:column;align-items:center;justify-content:center}.ConfirmLicenseRemovalModal .content-body .title{margin:10px 0;color:var(--sys-denim-center-channel-text);font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.ConfirmLicenseRemovalModal .content-body .subtitle{width:90%;color:var(--sys-denim-center-channel-text);font-size:14px;font-style:normal;font-weight:normal;line-height:20px;text-align:center}.ConfirmLicenseRemovalModal .content-body .alert-svg{margin-bottom:15px}.ConfirmLicenseRemovalModal .content-footer{display:flex;align-items:center;justify-content:center;margin-top:20px}.ConfirmLicenseRemovalModal .content-footer button{height:40px;border-radius:4px;margin-top:15px !important;margin-left:10px}.ConfirmLicenseRemovalModal .modal-footer{border-top:none !important;background:none !important}
.EELicenseModal .modal-header{background:none !important}.EELicenseModal .modal-header button.close span{color:rgba(63,67,80,.75) !important}.EELicenseModal .title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.EELicenseModal .enterprise-license-text{max-height:200px;padding:10px;background:#fff;overflow-y:auto;text-align:justify}.EELicenseModal .content-footer{display:flex}.EELicenseModal .content-footer button{border-radius:4px;margin-top:15px !important;margin-left:auto}.EELicenseModal .modal-footer{border-top:none !important}
.UploadLicenseModal .modal-header{border-bottom:none !important;background:none !important}.UploadLicenseModal .modal-header button.close span{color:rgba(63,67,80,.75) !important}.UploadLicenseModal .modal-body{padding-top:0 !important;padding-bottom:24px !important}.UploadLicenseModal .content-body{display:flex;flex-direction:column;align-items:center;justify-content:center}.UploadLicenseModal .content-body .svg-image{margin-bottom:15px}.UploadLicenseModal .content-body .hands-svg{margin-top:0;margin-bottom:15px}.UploadLicenseModal .content-body .title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.UploadLicenseModal .content-body .subtitle{width:90%;color:#3f4350;font-size:14px;font-style:normal;font-weight:normal;line-height:20px;text-align:center}.UploadLicenseModal .content-body .file-upload{width:90%;padding:12px;border:1px solid rgba(63,67,80,.32);border-radius:4px;margin-top:15px}.UploadLicenseModal .content-body .file-upload__titleSection{color:rgba(63,67,80,.75);font-size:12px;font-weight:bold;line-height:16px}.UploadLicenseModal .content-body .file-upload__inputSection{display:flex;justify-content:space-between;margin-top:10px}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section{display:flex}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section svg{margin-right:5px}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section .file-size{margin-left:20px}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload{position:relative;display:flex;align-self:flex-end;margin-left:auto}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload a{color:#1c58d9;font-weight:600}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload input{position:absolute;z-index:5;top:0;left:0;width:100%;height:100%;padding-left:100%;cursor:pointer}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload input[disabled]{cursor:not-allowed}.UploadLicenseModal .content-body .serverError{display:flex;width:90%;margin-top:5px;color:var(--error-text);float:left}.UploadLicenseModal .content-body .serverError i{display:inline;margin-right:5px}.UploadLicenseModal .content-body .serverError span.server-error-text{display:inline-flex}.UploadLicenseModal .content-footer{display:flex;flex-direction:column;align-items:center;justify-content:center;margin-top:20px}.UploadLicenseModal .content-footer button{height:48px;padding:5px 24px;border:0 !important;border-radius:4px;margin-top:15px !important;font-size:16px;font-weight:600;line-height:18px}.UploadLicenseModal .modal-footer{border-top:none !important;background:none !important}
.RenewLicenseCard__buttons{display:flex}.RenewLicenseCard__text-title{margin-bottom:5px;color:var(--sys-sidebar-text-active-border);font-family:"Open Sans",sans-serif;font-size:18px;font-weight:600;line-height:24px}.RenewLicenseCard__text-title.critical{color:var(--sys-error-text)}.RenewLicenseCard__text-description{margin-bottom:5px;color:var(--sys-center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;line-height:30px}.RenewLicenseCard__text-description.bolder{font-weight:600}.RenewLicenseCard__licensedUsersNum,.RenewLicenseCard__activeUsersNum{display:inline-block}.RenewLicenseCard__activeUsersNum{margin-left:25px}.RenewLicenseCard .annnouncementBar__purchaseNow{display:block;padding:12px 20px;border:none;border-radius:4px;margin-top:15px;background:var(--sys-button-bg);color:var(--sys-button-color)}.RenewLicenseCard .annnouncementBar__purchaseNow span{font-size:14px;font-weight:600;line-height:14px}.RenewLicenseCard__alertBanner{padding:12px 20px;border:1px solid rgba(var(--error-text-color-rgb), 0.16);margin-top:4px;background:rgba(var(--error-text-color-rgb), 0.08)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.StarterEditionRightPannel .svg-image{text-align:center}.StarterEditionRightPannel .svg-image svg{margin:0 auto 24px auto}.StarterEditionRightPannel .upgrade-title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.StarterEditionRightPannel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.StarterEditionRightPannel .advantages-list .item{margin:10px 0}.StarterEditionRightPannel .advantages-list .item i{margin-right:5px}.StarterEditionRightPannel .advantages-list :last-child{color:rgba(63,69,80,.64)}.StarterEditionRightPannel .purchase_buttons{display:flex;flex-direction:row;justify-content:center;margin-top:20px}@media screen and (max-width: 1130px){.StarterEditionRightPannel .purchase_buttons{flex-direction:column}.StarterEditionRightPannel .purchase_buttons button{width:100% !important}.StarterEditionRightPannel .purchase_buttons button.contact-us{margin-top:10px;margin-left:0 !important}}.StarterEditionRightPannel .upgrade-error{margin-top:10px}.StarterLeftPanel{position:relative}.StarterLeftPanel .PlanDetails__viewPlansButton{position:absolute;right:10px;display:block;margin-left:auto}.StarterLeftPanel .pre-title{margin-bottom:10px;color:rgba(63,67,80,.75) !important;font-size:12px;font-weight:600;line-height:16px}.StarterLeftPanel .title{color:#3f4350;font-family:Metropolis;font-size:18px;font-weight:700;line-height:24px}.StarterLeftPanel .subtitle{color:#3d3c40;font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.StarterLeftPanel .content{margin:25px 0;font-size:12px}.StarterLeftPanel .licenseInformation{border-radius:4px}.StarterLeftPanel .licenseInformation .licenseKeyTitle{font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.StarterLeftPanel .licenseInformation .uploadButtons{margin-top:10px}.StarterLeftPanel .licenseInformation .uploadButtons input{display:hidden}.StarterLeftPanel .licenseInformation .uploadButtons .help-text{font-size:12px}
.TeamEditionRightPanel .svg-image{text-align:center}.TeamEditionRightPanel .svg-image svg{margin:0 auto 24px auto}.TeamEditionRightPanel .upgrade-title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.TeamEditionRightPanel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.TeamEditionRightPanel .advantages-list .item{margin:10px 0}.TeamEditionRightPanel .advantages-list .item i{margin-right:5px}.TeamEditionRightPanel .advantages-list :last-child{color:rgba(63,69,80,.64)}.TeamEditionRightPanel button,.TeamEditionRightPanel a.btn{width:100%;border-radius:4px;margin:5px auto}.TeamEditionRightPanel .upgrade-error{margin-top:10px}.TeamEditionRightPanel .upgrade-error.unsupported .form-group{margin-bottom:0}.TeamEditionLeftPanel__Header{display:flex;align-items:center;justify-content:space-between;gap:8px}.TeamEditionLeftPanel__Title{display:flex;align-items:center;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:18px;font-weight:600;gap:8px}.TeamEditionLeftPanel__LicenseNotices{margin-top:20px}
.RenewLicenseCard.TrialLicense .TrialLicenseCard__text-title{margin-bottom:22px;color:var(--sys-button-bg);font-size:18px;font-style:normal;font-weight:600;line-height:18px}.RenewLicenseCard.TrialLicense .RenewLicenseCard__buttons .contact_us_primary_cta{margin-left:0px}.RenewLicenseCard.TrialLicense .RenewLicenseCard__text-description{margin-bottom:16px;line-height:20px}.RenewLicenseCard.TrialLicense button{display:inline-block;margin-top:0}
.purchase-card{display:flex}.top-wrapper{display:flex}.top-wrapper .left-panel{width:568px}.top-wrapper .left-panel .panel-card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08)}.top-wrapper .right-panel{width:332px;margin-left:20px}.top-wrapper .right-panel .panel-card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;background:var(--sys-center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08)}.top-wrapper .right-panel .panel-card.entry{padding:24px;padding-top:40px}.top-wrapper .terms-and-policy{margin-top:15px}.top-wrapper .compare-plans-text{margin-top:15px}.banner-start-trial .license-trial-legal-terms{color:#3f4350}.admin-console__banner_section{margin-bottom:20px}.admin-console__banner_section:empty{margin-bottom:0px}.admin-console__banner_section .AlertBanner:not(:last-child){margin-bottom:20px}.current-plan-legend{margin:10px 0 20px 0;color:#3db887;font-size:14px;font-style:normal;font-weight:600;line-height:14px}.current-plan-legend i{margin-right:5px;margin-left:-5px}.upgrade-error.unsupported .form-group{margin-bottom:0}
.InlineSectionFeatureDiscovery{display:flex;align-items:center;padding:40px;border:solid 1px rgba(var(--center-channel-color-rgb), 0.08);border-radius:var(--radius-m);margin:20px 0;background-color:var(--center-channel-bg);gap:40px}.InlineSectionFeatureDiscovery__image{flex-shrink:0}.InlineSectionFeatureDiscovery__content{flex:1}.InlineSectionFeatureDiscovery__badge{margin-bottom:16px}.InlineSectionFeatureDiscovery__badge .LicenseSkuBadge{margin-left:0}.InlineSectionFeatureDiscovery__title{margin-bottom:12px !important;color:var(--center-channel-color);font-size:18px;font-weight:600;line-height:24px}.InlineSectionFeatureDiscovery__description{margin:0 0 24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;line-height:20px}.InlineSectionFeatureDiscovery__actions{display:flex;align-items:center}
.autotranslation-section-header{display:flex;width:100%;min-width:0;align-items:flex-start;justify-content:space-between;gap:24px}.autotranslation-section-toggle{display:flex;align-items:center;align-self:center}.localization-section-title{display:flex;margin:unset;font-size:16px;gap:6px}.localization-section-title .Tag{position:relative;top:-1px}.localization-section-description{margin-bottom:0;color:var(--center-channel-color-72);font-size:14px;font-style:normal;font-weight:400}.ai-service-help-text{display:flex;flex-direction:column;gap:12px}.ai-service-help-text .agents-config-link{opacity:1}.auto-translation-provider-description{color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.auto-translation-provider-body{display:flex;flex-direction:column;gap:12px}.auto-translation-provider-error-message{display:flex;align-items:center;color:var(--error-text);font-size:12px;font-weight:400;gap:4px;line-height:16px}.auto-translation-provider-error-message .icon{color:var(--error-text);font-size:14px}.autotranslation-provider-error .form-control{border-color:var(--error-text);box-shadow:none}.agents-config-link{display:inline-block;width:fit-content;align-items:center;color:var(--link-color);cursor:pointer;font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600;line-height:16px;text-decoration:none}.agents-config-link .icon{color:var(--link-color);font-size:12px}.autotranslation-error.error-message{color:var(--error-text);font-size:12px;font-weight:400}
.autoTranslationInfo{margin-bottom:32px}.autoTranslationInfo .sectionNoticeTitle{margin-bottom:0}
.OpenIdConvert{display:grid;padding:0;border:1px solid rgba(87,158,255,.24);border-radius:4px;margin-bottom:25px;background-color:rgba(87,158,255,.08);font-family:Open Sans;font-style:normal;font-weight:normal;grid-template-columns:auto 1fr}.OpenIdConvert p{margin:0 0 8px}.OpenIdConvert .btn{width:191px;height:32px;border-radius:4px;margin-right:10px;background:#166de0;color:#fff;font-size:12px;font-weight:600;line-height:9px}.OpenIdConvert .btn:focus,.OpenIdConvert .btn:active,.OpenIdConvert .btn:focus:active{border-color:rgba(0,0,0,0);outline:none}.OpenIdConvert .btn-secondary{display:flex;min-width:100px;height:32px;align-items:center;justify-content:center;border-radius:4px;margin:0 10px 0 0;text-decoration:none}.OpenIdConvert .btn-secondary:hover{background-color:#166de0;color:#fff}.OpenIdConvert_actionWrapper{z-index:100;display:flex;width:100%;height:40px;-webkit-flex:0 0 60px;flex:0 0 60px;align-items:center;padding:4 0 4px;border-top:1px solid alpha-color(rgb(0, 0, 0), 0.1)}.OpenIdConvert_copyWrapper{padding:16px 16px 16px 12px}.OpenIdConvert_imageWrapper{padding:16px 0 0 16px}.OpenIdConvert_image{height:18px}.OpenIdConvert__heading{padding-bottom:8px;font-size:14px;font-weight:600;line-height:20px}
.PermissionPolicySettings .form-group{min-height:40px}.PermissionPolicySettings .vertically-centered-label{padding-top:7px}.PermissionPolicySettings .delete-policy .btn-primary:not(:disabled){background-color:var(--dnd-indicator)}.PermissionPolicySettings .admin-console__warning-notice{margin-bottom:16px}.PermissionPolicySettings .admin-console__warning-notice h4{margin-bottom:0}.PermissionPolicySettings .pp-info-banner{display:flex;align-items:flex-start;padding:16px;border-radius:4px;margin-bottom:20px;background-color:rgba(var(--button-bg-rgb), 0.08);gap:12px}.PermissionPolicySettings .pp-info-banner>.icon{color:var(--button-bg);font-size:20px;line-height:1}.PermissionPolicySettings .pp-info-banner .pp-info-banner-content{display:flex;flex-direction:column;gap:4px}.PermissionPolicySettings .pp-info-banner .pp-info-banner-content .pp-info-banner-title{color:var(--center-channel-color);font-size:14px;font-weight:600}.PermissionPolicySettings .pp-info-banner .pp-info-banner-content .pp-info-banner-link{color:var(--button-bg);text-decoration:underline}.PermissionPolicySettings .pp-info-banner .pp-info-banner-content .pp-info-banner-subtitle{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:13px}.PermissionPolicySettings .pp-role-selector .pp-role-selector-label{display:block;margin-bottom:12px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px}.PermissionPolicySettings .pp-role-dropdown-button{display:flex;width:350px;max-width:100%;align-items:center;justify-content:space-between;padding:10px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);color:var(--center-channel-color);cursor:pointer;font-size:14px}.PermissionPolicySettings .pp-role-dropdown-button:hover{border-color:rgba(var(--center-channel-color-rgb), 0.32)}.PermissionPolicySettings .pp-role-dropdown-button:focus{border-color:var(--button-bg);box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.3);outline:none}.PermissionPolicySettings .pp-role-dropdown-button .icon{color:rgba(var(--center-channel-color-rgb), 0.56);font-size:18px}.PermissionPolicySettings .pp-permissions-table{overflow:hidden;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);border-radius:4px;margin-bottom:12px}.PermissionPolicySettings .pp-permissions-table-header{padding:10px 16px;background:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-weight:600;text-transform:uppercase}.PermissionPolicySettings .pp-permissions-table-empty{padding:24px 16px;color:rgba(var(--center-channel-color-rgb), 0.48);font-size:14px;text-align:center}.PermissionPolicySettings .pp-permissions-table-row{display:flex;align-items:center;justify-content:space-between;padding:10px 16px}.PermissionPolicySettings .pp-permissions-table-row:not(:last-child){border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.PermissionPolicySettings .pp-permissions-table-row .pp-permission-label{font-size:14px}.PermissionPolicySettings .pp-permissions-table-row .pp-permission-remove{display:flex;align-items:center;justify-content:center;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.PermissionPolicySettings .pp-permissions-table-row .pp-permission-remove:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--error-text)}.PermissionPolicySettings .pp-permissions-table-row .pp-permission-remove .icon{font-size:16px}.PermissionPolicySettings .pp-add-permission-button{display:inline-flex;align-items:center;padding:6px 12px;border:1px solid var(--button-bg);border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);cursor:pointer;font-size:14px;font-weight:600;gap:6px}.PermissionPolicySettings .pp-add-permission-button .icon{font-size:16px}.PermissionPolicySettings .pp-add-permission-button:hover{background:rgba(var(--button-bg-rgb), 0.08)}.PermissionPolicySettings .pp-error{display:flex;align-items:center;margin-left:12px;color:var(--error-text);font-size:14px}.PermissionPolicySettings .pp-error i{margin-right:4px;font-size:16px}#pp-role-selector-menu.MuiMenuList-root,#pp-role-selector-menu{max-width:360px}#pp-role-selector-menu .MuiMenuItem-root{white-space:normal !important}#pp-role-selector-menu .label-elements{min-width:0;flex-shrink:1}#pp-role-selector-menu .label-elements>:first-child,#pp-role-selector-menu .label-elements>:only-child,#pp-role-selector-menu .label-elements>:last-child{white-space:normal !important;word-break:break-word}#pp-role-selector-menu .label-elements>:last-child{line-height:1.4}
.ChannelsInput.empty .channels-input__control .channels-input__input{border-bottom:0}.ChannelsInput .channels-input__control{min-height:48px;padding:0 16px;border-color:rgba(var(--center-channel-color-rgb), 0.2);background:var(--center-channel-bg);box-shadow:none;color:var(--center-channel-color);transition:none}.ChannelsInput .channels-input__control:hover{border-color:rgba(var(--center-channel-color-rgb), 0.2);cursor:text}.ChannelsInput .channels-input__control--is-focused,.ChannelsInput .channels-input__control--menu-is-open{padding:0 15px;border-width:2px;border-color:var(--button-bg);transition:none}.ChannelsInput .channels-input__control--is-focused:hover,.ChannelsInput .channels-input__control--menu-is-open:hover{border-color:var(--button-bg)}.ChannelsInput .channels-input__control--is-focused .channels-input__value-container .channels-input__input,.ChannelsInput .channels-input__control--menu-is-open .channels-input__value-container .channels-input__input{border-bottom:0}.ChannelsInput .channels-input__control .channels-input__input{border-bottom:1px dotted red}.ChannelsInput .channels-input__control .channels-input__input>div{width:1px}.ChannelsInput .channels-input__value-container{padding:0;margin-left:0}.ChannelsInput .channels-input__placeholder{color:rgba(var(--center-channel-color-rgb), 0.75)}.ChannelsInput .channels-input__input-container{color:var(--center-channel-color)}.ChannelsInput .channels-input__input{margin-left:6px;color:var(--center-channel-color)}.ChannelsInput .channels-input__input .a11y--focused{box-shadow:none}.ChannelsInput input{height:inherit}.ChannelsInput .channels-input__menu{margin-top:0;background:var(--center-channel-bg);box-shadow:0 0 0 0 rgba(0,0,0,.1),0 4px 11px rgba(0,0,0,.1);color:var(--center-channel-color)}.ChannelsInput .channels-input__menu-list{padding:8px 0;border:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelsInput .channels-input__menu-list:empty{display:none}.ChannelsInput .channels-input__menu-notice{display:flex;height:44px;align-items:center;justify-content:center;padding:12px;border-radius:4px 4px 0 0}.ChannelsInput .channels-input__option{display:flex;height:44px;align-items:center;padding:12px;cursor:pointer;font-size:14px}.ChannelsInput .channels-input__option--no-matches{color:rgba(var(--center-channel-color-rgb), 0.75);text-align:center}.ChannelsInput .channels-input__option--no-matches span{width:100%}.ChannelsInput .channels-input__option--no-matches strong{font-weight:600}.ChannelsInput .channels-input__option:first-child{border-radius:4px 4px 0 0}.ChannelsInput .channels-input__option:last-child{border-radius:0 0 4px 4px}.ChannelsInput .channels-input__option--is-focused{background:rgba(var(--button-bg-rgb), 0.08)}.ChannelsInput .channels-input__option--no-matches:hover{background:none;cursor:default}.ChannelsInput .channels-input__option .public-channel-icon,.ChannelsInput .channels-input__option .private-channel-icon{display:flex;width:18px;height:18px;align-items:center;margin-right:8px}.ChannelsInput .channels-input__option .public-channel-icon svg,.ChannelsInput .channels-input__option .private-channel-icon svg{width:18px;height:18px;fill:rgba(var(--center-channel-color-rgb), 0.75)}.ChannelsInput .channels-input__option .channel-name{color:rgba(var(--center-channel-color-rgb), 0.75)}.ChannelsInput .channels-input__option .channel-name::before{padding-left:5px;content:"("}.ChannelsInput .channels-input__option .channel-name::after{content:")"}.ChannelsInput .show{display:block}.ChannelsInput .channels-input__multi-value{align-items:center;padding:4px;border-radius:16px;margin:4px 12px 4px -4px;background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.ChannelsInput .channels-input__multi-value__label{display:flex;align-items:center;padding:0;color:var(--center-channel-color);font-size:1.2rem}.ChannelsInput .channels-input__multi-value__label .public-channel-icon,.ChannelsInput .channels-input__multi-value__label .private-channel-icon{display:flex;width:24px;height:24px;padding:4px;border-radius:16px;margin-right:4px;background:rgba(var(--center-channel-color-rgb), 0.75)}.ChannelsInput .channels-input__multi-value__label .public-channel-icon svg{width:16px;height:16px;fill:rgba(var(--button-color-rgb), 0.8)}.ChannelsInput .channels-input__multi-value__label .private-channel-icon svg{width:14px;height:14px;margin:0 1px;fill:rgba(var(--button-color-rgb), 0.8)}.ChannelsInput .channels-input__multi-value__label .channel-name{display:none}.ChannelsInput .channels-input__multi-value__label .selected-hidden{display:none}.ChannelsInput .channels-input__multi-value__remove{display:flex;height:20px;align-items:center;padding:0px 4px 2px 6px;cursor:pointer}.ChannelsInput .channels-input__multi-value__remove span{display:flex;width:14px;height:14px}.ChannelsInput .channels-input__multi-value__remove:hover{background:none}.ChannelsInput .channels-input__multi-value__remove svg{width:16px;height:16px;fill:rgba(var(--center-channel-color-rgb), 0.75);opacity:.73}.ChannelsInput .channels-input__multi-value__remove svg:hover{fill:rgba(var(--center-channel-color-rgb), 1)}
.LogTable{overflow:hidden}.LogTable .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}.LogTable .DataGrid .DataGrid_cell>.timestamp{display:flex;width:100%;align-items:center;cursor:pointer}.LogTable .btn-inverted{border:2px solid var(--button-bg);border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);font-weight:bold;line-height:12px}.LogTable .btn-dangerous{border:2px solid var(--dnd-indicator);border-radius:4px;background:rgba(0,0,0,0);color:var(--dnd-indicator);font-weight:bold;line-height:16px}
.user-property-field-dotmenu-menu-button{height:40px;justify-content:start;border-color:rgba(0,0,0,0);border-radius:0;box-shadow:none;font-weight:normal}.user-property-field-dotmenu-menu-button:hover,.user-property-field-dotmenu-menu-button:focus{border-color:rgba(0,0,0,0);box-shadow:none}.user-property-field-dotmenu-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.user-property-field-dotmenu-menu-button:focus,.user-property-field-dotmenu-menu-button[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08)}.user-property-field-dotmenu-menu-button.deleted{color:#d24b4e;text-decoration:line-through}.user-property-field-dotmenu-menu-button.strong{font-size:14px;font-style:normal;font-weight:600}.user-property-field-dotmenu__chip{padding:4px 12px;border-radius:12px;background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color);font-size:12px;font-style:normal;font-weight:600}
.orphaned-field-delete-button{padding:4px 8px}.orphaned-field-delete-button:hover:not(:disabled){background:rgba(var(--error-text-color-rgb), 0.08)}.orphaned-field-delete-button:disabled{cursor:not-allowed;opacity:.4}
.field-type-selector-menu-button{width:100%;height:40px;justify-content:start;border-color:rgba(0,0,0,0);border-radius:0;box-shadow:none;font-weight:normal}.field-type-selector-menu-button:hover,.field-type-selector-menu-button:focus{border-color:rgba(0,0,0,0);box-shadow:none}.field-type-selector-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.field-type-selector-menu-button:focus,.field-type-selector-menu-button[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08)}.field-type-selector-menu-button.deleted{color:#d24b4e;text-decoration:line-through}.field-type-selector-menu-button.strong{font-size:14px;font-style:normal;font-weight:600}
.user-property-field-values{display:flex;align-items:center;padding:0 12px;color:rgba(var(--center-channel-color-rgb), 0.75);gap:4px}.user-property-field-values__chip-link{padding:4px 12px;border-radius:12px;background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color);font-size:12px;font-style:normal;font-weight:600}.user-property-field-values__chip-link:hover,.user-property-field-values__chip-link:focus{border-color:rgba(0,0,0,0);box-shadow:none;text-decoration:none}.user-property-field-values__chip-link:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.user-property-field-values__chip-link:focus,.user-property-field-values__chip-link[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08)}
#SystemRoles{margin-top:0}#SystemRoles .SystemRoles .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}#SystemRoles .SystemRoles .DataGrid .DataGrid_cell{text-overflow:unset;white-space:normal}#SystemRoles .SystemRoles .DataGrid .DataGrid_cell .SystemRoles_editRow{padding-right:20px}
#SystemRolePermissions{margin-top:0}.SystemRolePermissions{padding:2rem 2rem 2rem 2rem;background:#f5f5f5;color:rgba(var(--sys-center-channel-color-rgb), 0.87)}.SystemRolePermissions .PermissionRow:nth-child(even){background:hsla(0,0%,100%,.5)}.SystemRolePermissions .PermissionRow .PermissionSection{display:flex;height:auto;flex-direction:row}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText{display:flex;flex-direction:column;flex-grow:3;align-content:flex-start;padding:14px 16px;margin-top:10px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText .PermissionSectionText_title{color:rgba(var(--sys-center-channel-color-rgb), 0.87);font-size:14px;font-weight:600}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText .PermissionSectionText_description{font-size:12px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown{padding:0 16px;margin:auto}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .Menu__content{min-width:256px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper{box-sizing:border-box;border-radius:4px;background:rgba(var(--sys-center-channel-color-rgb), 0.04)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton{display:flex;width:132px;height:32px;box-sizing:border-box;justify-content:space-between;padding:1px 0 1px 4px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);border-radius:4px;background:var(--sys-center-channel-bg);color:var(--sys-center-channel-color);font-size:12px;font-style:normal;font-weight:normal;line-height:28px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton:hover{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.48)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_text{max-width:230px;flex-grow:3;padding-left:8px;overflow-x:hidden;text-align:left;text-overflow:ellipsis}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_more{margin-right:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.75)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_icon{min-width:32px;height:31px;border-left:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);margin-top:-1px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_icon .Icon{display:flex;width:14px;height:14px;padding-top:8px;margin-right:0;margin-left:6px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper[disabled]{opacity:1}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper[disabled] .PermissionSectionDropdownButton{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:var(--sys-center-channel-color)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .PermissionSectionDropdownOptions_description{padding-bottom:4px;line-height:16px;white-space:normal}.SystemRolePermissions .PermissionRow .PermissionSubsectionsToggle{margin:0;line-height:16px}.SystemRolePermissions .PermissionRow .PermissionSubsectionsToggle button{font-size:12px}.SystemRolePermissions .PermissionRow .PermissionSubsections{padding-left:16px;border-left:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);margin:0 0 14px 16px}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection{height:auto;padding:4px 0}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionText{padding:0;margin:auto}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionText .PermissionSectionText_title{font-size:12px;font-weight:400}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSection_description{margin:0;font-size:10px;font-weight:600;line-height:15px}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSection_description span{border-radius:2px;background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionDropdown{padding:0 16px;margin:0}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection:last-of-type{padding-bottom:0}.SystemRolePermissions .PermissionSectionDropdownOptions .PermissionSectionDropdownOptions_label{color:var(--sys-center-channel-color);font-size:14px}.SystemRolePermissions .PermissionSectionDropdownOptions .PermissionSectionDropdownOptions_description{color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px}.SystemRolePermissionsList{margin-top:12px}.SystemRolePermissionsList li:not(:last-child){margin-bottom:8px}
.AdminUserCard{padding:0;border-radius:2px;margin:2em 0 1em;box-shadow:0 1px 2px 0 rgba(0,0,0,.5)}.AdminUserCard .noUserBody{display:flex;min-height:20vh;align-items:center;justify-content:center}.AdminUserCard__header{display:flex;height:92px;flex-direction:row;align-items:flex-start;padding:0 20px 0 30px;background-color:#295eb9}.AdminUserCard__header .Avatar.Avatar-xxl{border:solid 2px #fff}.AdminUserCard__body{padding:12px 20px 20px 178px;background-color:#fff}.AdminUserCard__footer{display:flex;flex-direction:row;padding:20px;border-top:solid 1px rgba(0,0,0,.2);background-color:#fff}.AdminUserCard__user-info{overflow:hidden;min-width:0;align-self:flex-end;padding:0;margin-left:20px;color:#fff;font-size:20px;font-weight:normal;text-overflow:ellipsis}.AdminUserCard__user-nickname{opacity:.5}.AdminUserCard__user-id{align-self:flex-end;margin-left:auto;color:#fff;font-size:12px;opacity:.5}
.ResetPasswordModal__body,.ResetEmailModal__body{display:flex;flex-direction:column;gap:20px}.ResetPasswordModal .Input_container .Input_fieldset,.ResetEmailModal .Input_container .Input_fieldset{background-color:var(--center-channel-bg)}.ResetPasswordModal .Input_container .Input_legend,.ResetEmailModal .Input_container .Input_legend{background-color:var(--center-channel-bg)}.ResetPasswordModal .Input_container .Input_wrapper,.ResetEmailModal .Input_container .Input_wrapper{background-color:rgba(0,0,0,0)}.ResetPasswordModal .Input_container .Input.form-control,.ResetPasswordModal .Input_container .form-control,.ResetPasswordModal .Input_container input.form-control,.ResetPasswordModal .Input_container input,.ResetEmailModal .Input_container .Input.form-control,.ResetEmailModal .Input_container .form-control,.ResetEmailModal .Input_container input.form-control,.ResetEmailModal .Input_container input{height:auto;border:none !important;background:none !important;background-color:rgba(0,0,0,0) !important;box-shadow:none !important}.ResetPasswordModal .Input_container .Input.form-control:focus,.ResetPasswordModal .Input_container .form-control:focus,.ResetPasswordModal .Input_container input.form-control:focus,.ResetPasswordModal .Input_container input:focus,.ResetEmailModal .Input_container .Input.form-control:focus,.ResetEmailModal .Input_container .form-control:focus,.ResetEmailModal .Input_container input.form-control:focus,.ResetEmailModal .Input_container input:focus{border:none !important;background:none !important;background-color:rgba(0,0,0,0) !important;box-shadow:none !important}.ResetPasswordModal .Input_container .Input.form-control:hover,.ResetPasswordModal .Input_container .form-control:hover,.ResetPasswordModal .Input_container input.form-control:hover,.ResetPasswordModal .Input_container input:hover,.ResetEmailModal .Input_container .Input.form-control:hover,.ResetEmailModal .Input_container .form-control:hover,.ResetEmailModal .Input_container input.form-control:hover,.ResetEmailModal .Input_container input:hover{background:none !important;background-color:rgba(0,0,0,0) !important}
.AbstractList{padding:1rem 2rem 2rem 2rem;transition:all .4s ease-in-out 0s}.AbstractList .AbstractList__header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);font-size:1.1em;font-weight:bold}.AbstractList .AbstractList__header .AbstractList__header-label{display:inline-block}.AbstractList .AbstractList__body{background:#f5f5f5}.AbstractList .AbstractList__body .AbstractList__loading{padding:40px;text-align:center}.AbstractList .AbstractList__body .AbstractList__empty{margin-top:1rem;background:hsla(0,0%,100%,.5);color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.AbstractList .AbstractList__body .AbstractList__empty span{display:inline-block;width:100%;height:100%;padding-top:20px;padding-bottom:20px}.AbstractList .AbstractList__footer{display:flex;height:auto;align-items:center;justify-content:flex-end;padding:5px;border-top:solid 1px rgba(0,0,0,.1);background:#fff}.AbstractList .AbstractList__footer .btn-tertiary{color:rgba(0,0,0,.5)}.AbstractList .AbstractList__footer .btn-tertiary.disabled{opacity:.5}.AbstractList .AbstractList__footer .counter{margin-bottom:2px;color:rgba(0,0,0,.5);font-size:1.1em}
.TeamRow:nth-child(odd){background:alpha-color(rgb(255, 255, 255), 0.5)}.TeamRow__row{display:flex;height:80px;flex-direction:row;align-items:center;border:2px solid rgba(0,0,0,0)}.TeamRow__row .TeamRow__team-name{display:inline-block;min-width:300px;flex-grow:3}.TeamRow__row .TeamRow__team-name .TeamIcon{margin-right:0}.TeamRow__row .TeamRow__team-name .TeamRow__team-description{min-width:276px;max-width:400px}.SystemUserDetail .TeamRow__col-description{min-width:276px;max-width:400px}.TeamRow__row .TeamRow__description{display:flex;overflow:hidden;width:150px;max-width:400px;height:100%;align-items:center}.TeamRow__row .TeamRow__description.adjusted{width:120px}.TeamRow__row .TeamRow__description i{margin-right:5px}.TeamRow__row .TeamRow__description>a{padding:3px 5px;color:#000;text-decoration:none}.TeamRow__row .TeamRow__description>a:hover{border-radius:3px;background-color:rgba(0,0,0,.15)}.TeamRow__row .TeamRow__description>a.warning{color:#d64946}.TeamRow__row .TeamRow__actions{display:flex;width:150px;max-width:400px;height:100%;align-items:center;justify-content:flex-end;padding-right:15px}.TeamRow__row .TeamIcon__content{opacity:1}
.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row{display:flex;margin-bottom:16px;gap:20px}.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row .field-column{min-width:0;flex:1}.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row .field-column.left{padding-right:10px}.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row .field-column.right{padding-left:10px}.SystemUserDetail .AdminUserCard__body label{display:block;font-weight:unset}.SystemUserDetail .AdminUserCard__body label>span:nth-child(1){display:block;margin-top:12px;margin-bottom:6px;font-size:12px;font-weight:bold}.SystemUserDetail .AdminUserCard__body label>span:nth-child(2){vertical-align:middle}.SystemUserDetail .AdminUserCard__body label input,.SystemUserDetail .AdminUserCard__body label select{display:inline-block;width:100%;max-width:320px}.SystemUserDetail .AdminUserCard__body label input.error,.SystemUserDetail .AdminUserCard__body label select.error{border-color:var(--error-text);box-shadow:0 0 0 1px var(--error-text)}.SystemUserDetail .AdminUserCard__body label .field-error{display:block;margin-top:4px;color:var(--error-text);font-size:12px}.SystemUserDetail .AdminUserCard__body label select[multiple]{min-height:80px}.SystemUserDetail .AdminUserCard__body .cpa-field{position:relative}.SystemUserDetail .AdminUserCard__body .cpa-section-divider{display:flex;align-items:center;padding-top:16px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin-top:8px;margin-bottom:8px}.SystemUserDetail .AdminUserCard__body .cpa-section-divider .cpa-section-header{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-weight:600;letter-spacing:.5px;text-transform:uppercase}.SystemUserDetail .AdminUserCard__body .user-property-field-values__sync-indicator{display:flex;align-items:center;margin-top:4px;color:rgba(var(--center-channel-color-rgb), 0.7);font-size:11px}.SystemUserDetail .AdminUserCard__body .user-property-field-values__sync-indicator svg{width:14px;height:14px;margin-right:6px;fill:rgba(var(--center-channel-color-rgb), 0.5)}.SystemUserDetail .AdminUserCard__body svg{display:inline-block;width:16px;height:16px;margin:0 8px 0 0;fill:rgba(var(--sys-color-sidebar-text-rgb), 0.6)}.SystemUserDetail .teamlistLoading{display:flex;min-height:20vh;align-items:center;justify-content:center}.SystemUserDetail .AdminUserCard__footer .manageUserSettingsBtn{margin-left:auto;cursor:pointer}@media(max-width: 768px){.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row{flex-direction:column;gap:0}.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row .field-column{padding:0}.SystemUserDetail .AdminUserCard__body .two-column-layout .field-row .field-column.right{margin-top:16px}}#admin-userDetail-saveChangesModal .changes-list{margin-top:10px;margin-bottom:10px}#admin-userDetail-saveChangesModal .password-confirmation-section{padding:12px;border-radius:4px;margin-top:16px;margin-bottom:16px;background-color:rgba(var(--center-channel-color-rgb), 0.04)}#admin-userDetail-saveChangesModal .password-confirmation-section .password-input-wrapper{margin-top:12px}#admin-userDetail-saveChangesModal .password-confirmation-section .password-input-wrapper input[type=password]{width:100%;max-width:320px}#admin-userDetail-saveChangesModal .password-confirmation-section .password-input-wrapper input[type=password].error{border-color:var(--error-text);box-shadow:0 0 0 1px var(--error-text)}#admin-userDetail-saveChangesModal .password-confirmation-section .password-input-wrapper .field-error{display:block;margin-top:8px;color:var(--error-text);font-size:12px}
.systemUsersColumnToggler{margin-inline-end:8px}#systemUsersColumnTogglerMenu i.icon.icon-checkbox-marked{color:var(--button-bg)}#systemUsersColumnTogglerMenu i.icon.icon-checkbox-blank-outline{color:rgba(var(--sys-center-channel-color-rgb), 0.24)}#systemUsersColumnTogglerMenu .systemUsersColumnToggler__lockedItem{pointer-events:auto}
.systemUsersDateRangeSelector{margin-inline-end:8px}.systemUsersDateRangeSelector .inputWithMenu input.form-control{width:120px}#systemUsersDateRangeSelectorMenu .systemUsersDateRangeSelector__trailing-message{color:rgba(var(--center-channel-color-rgb), 0.56);opacity:1}#systemUsersDateRangeSelectorMenu .systemUsersDateRangeSelector__trailing-message span{max-width:210px;text-wrap:wrap}#systemUsersDateRangeSelectorMenu i.icon-check{color:var(--button-bg)}
.upgrade-export-data-modal__svg-image{display:flex;justify-content:center;margin-top:24px}
.system-users-export__keyIndicator{position:relative;top:-6px;right:14px;display:flex;width:20px;height:20px;align-self:flex-start;justify-content:center;border-radius:12px;background:var(--online-indicator, #3db887)}.system-users-export__keyIndicator i{color:var(--center-channel-bg, #fff);font-size:12px}.system-users-export__keyIndicator i::before{margin:0}
.systemUsersFilterContainer{flex-grow:1}.systemUsersFilterPopoverContainer>#header{padding:20px 24px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin:unset;color:var(--sys-center-channel-color);font-size:14px;font-weight:600;line-height:14px}.systemUsersFilterPopoverContainer>.body{width:280px;padding:20px 24px 0 20px}.systemUsersFilterPopoverContainer>.body>*{margin-bottom:24px}.systemUsersFilterPopoverContainer>.body .DropdownInput.Input_container{margin-top:unset}.systemUsersFilterPopoverContainer .footer{display:flex;height:unset;justify-content:flex-end;margin-block-end:20px;margin-inline-end:24px}
.systemUsersSearch{width:360px;margin-inline-end:8px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}table.systemUsersTable thead tr th.actionsColumn{padding-inline-start:24px}table.systemUsersTable tbody tr td.usernameColumn>div{display:grid;width:max-content;gap:0 0;grid-auto-flow:row;grid-template-areas:"profilePictureContainer displayName" "profilePictureContainer userName" "profilePictureContainer error";grid-template-columns:56px 1fr;grid-template-rows:1fr 1fr}table.systemUsersTable tbody tr td.usernameColumn>div .profilePictureContainer{width:40px;height:40px;align-self:center;grid-area:profilePictureContainer}table.systemUsersTable tbody tr td.usernameColumn>div .profilePictureContainer>img{width:100%;height:100%;border-radius:40px;object-fit:cover}table.systemUsersTable tbody tr td.usernameColumn>div .displayName{display:flex;align-items:center;align-self:start;color:var(--sys-denim-button-bg);font-weight:600;grid-area:displayName;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}table.systemUsersTable tbody tr td.usernameColumn>div .displayName .icon{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.8)}table.systemUsersTable tbody tr td.usernameColumn>div .userName{align-self:start;grid-area:userName;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}table.systemUsersTable tbody tr td.usernameColumn>div .error{max-width:300px;align-self:start;grid-area:error;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;white-space:normal}table.systemUsersTable tbody tr td.actionsColumn>button{padding:0 12px}
.ChannelsList .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}.ChannelsList .DataGrid .DataGrid_cell .TeamList_editRow{padding-right:20px}.ChannelsList .DataGrid .DataGrid_cell .TeamList_channelDisplayName{color:#333;font-weight:600;opacity:.8}.ChannelsList .DataGrid .DataGrid_cell .channel-icon{display:inline-flex;width:16px;justify-content:center;margin-right:10px;font-size:120%;opacity:.8}.ChannelsList .DataGrid .DataGrid_cell .shared-channel-icon{color:#000}.ChannelsList .DataGrid .DataGrid_cell .row-content{display:flex;align-items:center}
.policy-table-container{width:100%;margin-block:-20px}.policy-table-container .policy-table{width:100%;margin-bottom:0;background-color:var(--center-channel-bg);border-collapse:collapse}.policy-table-container .policy-table th,.policy-table-container .policy-table td{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);line-height:20px;padding-block:16px;text-align:left;white-space:nowrap}.policy-table-container .policy-table thead tr{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.policy-table-container .policy-table th{background-color:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;font-weight:600}.policy-table-container .policy-table td{background-color:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px}.policy-table-container .policy-table td.policy-name{font-weight:600}.policy-table-container .policy-table tbody tr:last-child td{border-bottom:none}.policy-table-container .policy-table .text-right{width:50px;padding-right:16px;text-align:right}.policy-table-container .policy-table .policy-edit-icon{display:inline-flex;align-items:center;justify-content:center;color:rgba(var(--center-channel-color-rgb), 0.72);text-decoration:none}.policy-table-container .policy-table .policy-edit-icon:hover{color:rgba(var(--center-channel-color-rgb), 0.9)}.policy-table-container .policy-table .policy-edit-icon i{font-size:16px}.policy-table-container .policy-table .policy-remove-icon{display:inline-flex;align-items:center;justify-content:center;padding:0;border:none;margin-left:8px;background:none;color:rgba(var(--center-channel-color-rgb), 0.72);cursor:pointer;transform:translateY(-2px)}.policy-table-container .policy-table .policy-remove-icon:hover{color:var(--error-text)}.policy-table-container .policy-table .policy-remove-icon i{font-size:16px}#channel_access_control_with_policy .btn.btn-primary{border-color:var(--dnd-indicator);background-color:var(--dnd-indicator);color:var(--button-color)}#channel_access_control_with_policy .btn.btn-primary:hover,#channel_access_control_with_policy .btn.btn-primary:active,#channel_access_control_with_policy .btn.btn-primary:focus{border-color:rgba(var(--dnd-indicator-rgb), 0.88);background-color:rgba(var(--dnd-indicator-rgb), 0.88)}
.MemberListGroup .DataGrid{display:flex;width:100%;height:calc(90vh - 120px);flex-direction:column;padding:0}.MemberListGroup .DataGrid .DataGrid_rows{height:1px;flex-grow:500;overflow-y:scroll}.MemberListGroup .DataGrid .DataGrid_empty{margin:auto}
.channel-level-access-rules .channel-access-rules__editor{padding:16px}.channel-level-access-rules .channel-access-rules__editor .table-editor__actions-row{padding:12px}.channel-level-access-rules .channel-access-rules__error{display:flex;align-items:center;padding:12px;border:1px solid var(--error-text);border-radius:4px;margin-top:8px;background-color:var(--error-text-color);color:var(--error-text);font-size:14px;gap:8px}.channel-level-access-rules .channel-access-rules__error i{flex-shrink:0;font-size:16px}.channel-level-access-rules .channel-access-rules__auto-sync{margin-top:16px}.channel-level-access-rules .channel-access-rules__auto-sync-divider{height:1px;margin-bottom:16px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}.channel-level-access-rules .channel-access-rules__auto-sync-content{padding:16px}.channel-level-access-rules .channel-access-rules__auto-sync-label{display:flex;align-items:flex-start;margin-bottom:8px;cursor:pointer;gap:8px}.channel-level-access-rules .channel-access-rules__auto-sync-label:hover .channel-access-rules__auto-sync-text{color:var(--link-color)}.channel-level-access-rules .channel-access-rules__auto-sync-checkbox{flex-shrink:0;margin-top:2px}.channel-level-access-rules .channel-access-rules__auto-sync-text{color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px;transition:color .15s ease-in-out}.channel-level-access-rules .channel-access-rules__auto-sync-help{margin-left:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;line-height:16px}.channel-level-access-rules .channel-access-rules__test-section{padding-top:16px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-top:16px}.channel-level-access-rules .channel-access-rules__test-section .btn{height:auto;padding:8px 16px;font-size:14px;line-height:20px}.channel-level-access-rules .admin-panel__content{padding-bottom:0}.channel-level-access-rules .table-editor{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background-color:var(--center-channel-bg)}.channel-level-access-rules .table-editor .table-editor__header{padding:16px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);background-color:rgba(var(--center-channel-color-rgb), 0.04)}.channel-level-access-rules .table-editor .table-editor__body{padding:16px}@media screen and (max-width: 768px){.channel-level-access-rules .channel-access-rules__auto-sync-help{margin-top:8px;margin-left:0}.channel-level-access-rules .channel-access-rules__test-section .btn{width:100%}}.channel-access-rules-confirm-modal .modal-body{padding:24px}.channel-access-rules-confirm-modal .user-list{max-height:200px;padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:16px 0;background-color:rgba(var(--center-channel-color-rgb), 0.04);overflow-y:auto}.channel-access-rules-confirm-modal .user-list .user-item{display:flex;align-items:center;padding:4px 0;color:var(--center-channel-color);font-size:14px;gap:8px}.channel-access-rules-confirm-modal .user-list .user-item:not(:last-child){padding-bottom:8px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-bottom:8px}
.UserGrid_nameRow{display:flex;height:80px}.UserGrid_nameRow .UserGrid_name{display:flex;overflow:hidden;flex-direction:column;flex-grow:1;flex-shrink:1;align-self:center;padding-left:10px;text-overflow:ellipsis}.UserGrid_nameRow .UserGrid_name span{overflow:hidden;text-overflow:ellipsis}.UserGrid_removeRow{padding-right:20px}
.AdminChannelDetails .channel-team{margin-top:12px}.AdminChannelDetails .channel-organizations{margin-top:12px}.AdminChannelDetails .channel-organizations .shared-channel-icon{width:16px;height:16px;margin-right:4px;color:rgba(61,60,64,.64);font-size:16px;line-height:16px}.AdminChannelDetails .channel-organizations .shared-channel-icon::before{margin:0}
.UsersToRemove .DataGrid{display:flex;width:100%;height:calc(90vh - 190px);flex-direction:column;padding:0}.UsersToRemove .DataGrid .DataGrid_rows{height:1px;flex-grow:500;overflow-y:scroll}.UsersToRemove .DataGrid .DataGrid_empty{margin:auto}.UsersToRemove .UsersToRemoveGroups a{color:var(--sys-center-channel-color);text-decoration:none}.UsersToRemove .UsersToRemoveGroups a:hover{text-decoration:underline}
.TeamsList .DataGrid .DataGrid_row{cursor:pointer}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn{display:flex;height:80px;align-items:center}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_nameText{overflow:hidden;padding-right:40px;opacity:.8}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_nameText .archived-label{color:rgba(var(--center-channel-color-rgb), 0.75)}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList__lowerOpacity{opacity:.8}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_descriptionText{overflow:hidden;text-overflow:ellipsis}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamIcon{margin-right:12px;background:rgba(0,0,0,.12)}.TeamsList .DataGrid .DataGrid_cell .TeamList_managementText{opacity:.75}.TeamsList .DataGrid .DataGrid_cell .TeamList_editText{padding-right:20px}
.Accordion{width:100%;padding:0;margin:0;list-style:none}.Accordion .accordion-card{box-sizing:border-box;border:1px solid rgba(var(--center-channel-color-rgb) 0.08);border-radius:4px;background:var(--center-channel-bg);box-shadow:var(--elevation-1)}.Accordion .accordion-card .accordion-card:not(:first-of-type){border-top:0}.Accordion .accordion-card .accordion-card-header{display:flex;width:100%;flex-direction:row;align-items:flex-start;padding:15px 20px;border:0;background-color:var(--center-channel-bg);font-size:18px;font-weight:400}.Accordion .accordion-card .accordion-card-header__icon{width:fit-content;max-width:15%;padding:5px}.Accordion .accordion-card .accordion-card-header__body{display:flex;width:fit-content;max-width:80%;flex-direction:column;padding:5px}.Accordion .accordion-card .accordion-card-header__body__title{width:100%;margin:0}.Accordion .accordion-card .accordion-card-header__body__description{width:100%;margin:0}.Accordion .accordion-card .accordion-card-header__chevron{width:fit-content;max-width:5%;padding:5px;margin-left:auto;opacity:.5}.Accordion .accordion-card.active .accordion-card-header__chevron{transform:rotate(-180deg)}.Accordion .accordion-card .accordion-card-container{overflow:hidden;transition:height .2s ease-in-out}.Accordion .accordion-card .accordion-card-container__content{padding:15px 20px;border-top:1px solid rgba(var(--center-channel-color-rgb) 0.04)}
.error,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].error,.WorkspaceOptimizationDashboard button[class^=StyledChip].error{color:var(--sys-error-text)}.info,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].info,.WorkspaceOptimizationDashboard button[class^=StyledChip].info{color:var(--sys-sidebar-text-active-border)}.warning,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].warning,.WorkspaceOptimizationDashboard button[class^=StyledChip].warning{color:var(--sys-away-indicator-dark)}.ok,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].ok,.WorkspaceOptimizationDashboard button[class^=StyledChip].ok{color:var(--sys-online-indicator)}.scoreGraph,.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .successImageScore,.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .alertImageScore{display:flex;width:112px;height:112px;align-items:center;justify-content:center;border-radius:50%}.WorkspaceOptimizationDashboard button[class*=" StyledChip"],.WorkspaceOptimizationDashboard button[class^=StyledChip]{width:120px;height:24px;justify-content:space-around;border:none;margin-right:8px;margin-bottom:0;box-shadow:none;font-size:12px;font-style:normal;font-weight:bold;line-height:16px;text-align:center}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].error,.WorkspaceOptimizationDashboard button[class^=StyledChip].error{background-color:rgba(var(--sys-error-text-color-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].info,.WorkspaceOptimizationDashboard button[class^=StyledChip].info{background-color:rgba(var(--sys-sidebar-text-active-border-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].warning,.WorkspaceOptimizationDashboard button[class^=StyledChip].warning{background-color:rgba(var(--sys-away-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].ok,.WorkspaceOptimizationDashboard button[class^=StyledChip].ok{background-color:rgba(var(--sys-online-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard div.OverallScore{display:flex;width:872px;box-sizing:border-box;align-items:center;padding:24px;border:1px solid rgba(var(--sys-denim-center-channel-text-rgb), 0.08) !important;border-radius:4px;margin-left:4px;background:var(--sys-center-channel-bg);box-shadow:var(--elevation-1)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg{display:flex;width:140px;height:140px;align-items:center}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .alertImageScore{background-color:rgba(var(--sys-error-text-color-rgb), 0.3)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .successImageScore{background-color:rgba(var(--sys-online-indicator-rgb), 0.3)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart{display:block;margin:5px auto}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.warning .circle{stroke:var(--sys-away-indicator)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.success .circle{stroke:var(--sys-online-indicator)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.info .circle{stroke:var(--sys-sidebar-text-active-border)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.error .circle{stroke:var(--sys-error-text)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart .circle{animation:progress 1s ease-out forwards;fill:none;stroke-width:3.55}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart .percentageOrNumber{font-family:Metropolis;font-size:.65em;font-weight:550}@keyframes progress{0%{stroke-dasharray:0 100}}.WorkspaceOptimizationDashboard div.OverallScore__content{display:flex;flex-direction:column;margin-left:24px}.WorkspaceOptimizationDashboard div.OverallScore__content__title{margin-bottom:8px;color:var(--sys-denim-center-channel-text);font-family:Metropolis,sans-serif;font-size:20px;font-weight:700;line-height:28px}.WorkspaceOptimizationDashboard div.OverallScore__content__description{margin-bottom:24px;color:var(--sys-denim-center-channel-text);font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.WorkspaceOptimizationDashboard div.OverallScore__content__chips{display:flex;flex-direction:row}.WorkspaceOptimizationDashboard div.OverallScore__content__chips button[class*=" StyledChip"],.WorkspaceOptimizationDashboard div.OverallScore__content__chips button[class^=StyledChip]{width:180px;height:32px;margin-right:16px}.WorkspaceOptimizationDashboard ul.Accordion{width:872px;margin-left:4px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card{overflow:hidden;box-sizing:border-box;border:var(--border-light);border-radius:var(--radius-s);margin-top:16px;background-color:var(--sys-center-channel-bg)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card:has(.accordion-card-header[role=button]):hover{border:var(--border-dark);box-shadow:var(--elevation-2)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header{max-height:92px;padding:0;background-color:var(--sys-center-channel-bg)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon{padding:0;margin:24px 0 24px 24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div{z-index:1;display:flex;width:44px;height:44px;align-items:center;justify-content:center;border-radius:50%;background-color:rgba(var(--sys-denim-center-channel-text-rgb), 0.16)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div.success{background-color:rgba(var(--sys-online-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div.success svg{opacity:1}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div svg{opacity:.73}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body{padding:0;margin:27px 0 26px 16px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body__title{margin-bottom:5px;color:#1c58d9;font-size:14px;font-weight:600;line-height:14px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body__description{color:#3d3c40;font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent{display:flex;flex-direction:row;align-items:flex-end;margin-top:34px;margin-left:auto}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent button[class*=" StyledChip"],.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent button[class^=StyledChip]{margin-right:24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__chevron{padding:0;margin:30px 30px 30px 0;font-size:24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content{padding:16px 24px;border-top:1px solid rgba(63,67,80,.06);background-color:#fff}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"],.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem]{padding:16px 0}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] h5,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] h5{margin-top:0;margin-bottom:4px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] i,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] i{margin-left:-5px;font-size:20px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] i.warning,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] i.warning{color:var(--sys-away-indicator)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons{display:flex;justify-content:flex-start;margin:15px 0 0 0}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons a,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons button{max-height:32px;padding:5px 20px !important;border-radius:4px !important;margin-top:0;margin-right:10px;font-weight:600}
.CircularChart .circular-chart{display:block;margin:5px auto}.CircularChart .circular-chart.warning .circle{stroke:var(--away-indicator)}.CircularChart .circular-chart.success .circle{stroke:var(--online-indicator)}.CircularChart .circular-chart.info .circle{stroke:var(--sidebar-text-active-border)}.CircularChart .circular-chart.error .circle{stroke:var(--error-text)}.CircularChart .circular-chart .circle-bg{fill:none;stroke:rgba(0,0,0,0);stroke-width:4.2}.CircularChart .circular-chart .circle{animation:progress 1s ease-out forwards;fill:none;stroke-width:3.2}@keyframes progress{0%{stroke-dasharray:0 100}}.CircularChart .percentageOrNumber{fill:var(--sys-center-channel-color);font-family:sans-serif;font-size:.5em;text-anchor:middle}
.CommercialSupportModal{padding:0 32px 32px 32px}.CommercialSupportModal .DownloadSupportPacket{margin-top:20px}.CommercialSupportModal .AlertBanner{margin-top:20px}.CommercialSupportModal__packet_contents_download{margin-top:20px;margin-bottom:12px}.CommercialSupportModal__options_checkbox_label{padding-left:12px;font-weight:500}.modal-header .modal-title{font-family:Metropolis,sans-serif;font-weight:600 !important}.CommercialSupportModal__error{margin-top:12px}.CommercialSupportModal__error .error-text{display:inline-block;color:var(--error-text);word-break:break-word}

/*# sourceMappingURL=242.3246ac699090755f4087.css.map*/